@@ -38,12 +38,14 @@
 #include "fnctdsk.h"
 #include "chgtype.h"
 #include "testdisk.h"
+#include "dirpart.h"
 #include "fat.h"
 #include "ntfs.h"
 #include "hfsp.h"
 #include "adv.h"
 #include "analyse.h"
 #include "intrface.h"
+#include "io_redir.h"
 
 #define INTER_ADV_X	0
 #define INTER_ADV_Y	23
@@ -172,7 +174,7 @@ void interface_adv(t_param_disk *disk_car, const int debug,const int dump_ind, c
       options="q";
       wmove(stdscr,5+2,0);
       wattrset(stdscr,A_STANDOUT);
-      wdoprintf(stdscr,"No partition avaible.");
+      wdoprintf(stdscr,"No partition available.");
       wattroff(stdscr,A_STANDOUT);
     }
     else
@@ -654,6 +656,7 @@ int ntfs_boot_sector(t_param_disk *disk_car, t_partition *partition, const int d
     { 'P', "Previous",""},
     { 'N', "Next","" },
     { 'Q', "Quit","Return to Advanced menu"},
+    { 'L', "List", "List directories and files" },
     { 'O', "Org. BS","Copy boot sector over backup sector"},
     { 'B', "Backup BS","Copy backup boot sector over boot sector"},
     { 'R', "Rebuild BS","Rebuild boot sector"},
@@ -673,7 +676,7 @@ int ntfs_boot_sector(t_param_disk *disk_car, t_partition *partition, const int d
       int opt_over=0;
       int opt_B=0;
       int opt_O=0;
-      options="DRM";
+      options="DRML";
       aff_copy(stdscr);
       wmove(stdscr,4,0);
       wdoprintf(stdscr,"%s",disk_car->description(disk_car));
@@ -732,11 +735,11 @@ int ntfs_boot_sector(t_param_disk *disk_car, t_partition *partition, const int d
       if(opt_over!=0)
       {
 	if(opt_B!=0 && opt_O!=0)
-	  options="DOBR";
+	  options="DOBRL";
 	else if(opt_B!=0)
-	  options="DBR";
+	  options="DBRL";
 	else if(opt_O!=0)
-	  options="DOR";
+	  options="DORL";
       }
       rescan=0;
     }
@@ -755,6 +758,11 @@ int ntfs_boot_sector(t_param_disk *disk_car, t_partition *partition, const int d
 	(*current_cmd)+=4;
 	command='D';
       }
+      else if(strncmp(*current_cmd,"list",4)==0)
+      {
+	(*current_cmd)+=4;
+	command='L';
+      }
       else if(strncmp(*current_cmd,"originalntfs",11)==0)
       {
 	(*current_cmd)+=11;
@@ -799,6 +807,16 @@ int ntfs_boot_sector(t_param_disk *disk_car, t_partition *partition, const int d
 	  rescan=1;
 	}
 	break;
+      case 'L':
+	if(strchr(options,'O')==NULL && strchr(options,'B')!=NULL)
+	{
+	  io_redir_add_redir(disk_car,partition->part_offset,sizeof(buffer_backup_bs),0,buffer_backup_bs);
+	  dir_partition(disk_car, partition, 0,current_cmd);
+	  io_redir_del_redir(disk_car,partition->part_offset);
+	}
+	else
+	  dir_partition(disk_car, partition, 0,current_cmd);
+	break;
       case 'M':
         repair_MFT(disk_car, partition, debug);
 	break;
