@@ -2,7 +2,7 @@
 
     File: bfs.c
 
-    Copyright (C) 1998-2005 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,14 +15,17 @@
     GNU General Public License for more details.
   
     You should have received a copy of the GNU General Public License along
-    with this program; if not, write the Free Software Foundation, Inc., 59
-    Temple Place - Suite 330, Boston MA 02111-1307, USA.
+    with this program; if not, write the Free Software Foundation, Inc., 51
+    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
  
 #include "types.h"
 #include "common.h"
@@ -35,12 +38,20 @@ static int test_BeFS(t_param_disk *disk_car, const struct disk_super_block*beos_
 
 int check_BeFS(t_param_disk *disk_car,t_partition *partition,const int debug)
 {
-  unsigned char buffer[8*DEFAULT_SECTOR_SIZE];
-  if(disk_car->read(disk_car,sizeof(buffer), &buffer, partition->part_offset)!=0)
+  unsigned char *buffer;
+  buffer=(unsigned char*)MALLOC(BFS_SUPERBLOCK_SIZE);
+  if(disk_car->read(disk_car,BFS_SUPERBLOCK_SIZE, buffer, partition->part_offset+0x200)!=0)
+  {
+    free(buffer);
     return 1;
-  if(test_BeFS(disk_car,(struct disk_super_block*)&buffer[0x200],partition,debug,0)!=0)
+  }
+  if(test_BeFS(disk_car,(struct disk_super_block*)buffer,partition,debug,0)!=0)
+  {
+    free(buffer);
     return 1;
-  set_BeFS_info(disk_car,(struct disk_super_block*)&buffer[0x200],partition,debug,0);
+  }
+  set_BeFS_info(disk_car,(struct disk_super_block*)buffer,partition,debug,0);
+  free(buffer);
   return 0;
 }
 
