@@ -55,18 +55,20 @@ void *MALLOC(size_t size)
   if(size>=512)
   {
     /* Warning, memory leak checker must be posix_memalign aware, otherwise reports may look strange */
-    if(posix_memalign(&res,4096,size)!=0)
+    if(posix_memalign(&res,4096,size)==0)
     {
-      ecrit_rapport("posix_memalign failed\n");
-      exit(EXIT_FAILURE);
+      memset(res,0,size);
+      return res;
     }
-    memset(res,0,size);
-    return res;
+    /*
+    ecrit_rapport("posix_memalign failed\n");
+    exit(EXIT_FAILURE);
+    */
   }
 #endif
   if((res=malloc(size))==NULL)
   {
-    ecrit_rapport("\nCan't allocate %u bytes of memory.\n",size);
+    ecrit_rapport("\nCan't allocate %lu bytes of memory.\n", (long unsigned)size);
     exit(EXIT_FAILURE);
   }
   memset(res,0,size);
