@@ -149,7 +149,7 @@ struct list_disk_struct
 
 struct systypes {
   const unsigned int part_type;
-  const unsigned char *name;
+  const char *name;
 };
 
 struct arch_fnct_struct
@@ -171,7 +171,7 @@ struct arch_fnct_struct
   int (*set_part_type)(t_partition *partition, unsigned int part_type);
   void (*init_structure)(const t_param_disk *disk_car,t_list_part *list_part, const int debug);
   int (*erase_list_part)(t_param_disk *disk_car);
-  const unsigned char *(*get_partition_name)(const t_partition *partition);
+  const char *(*get_partition_name)(const t_partition *partition);
   int (*is_part_known)(const t_partition *partition);
 };
 
