@@ -1,4 +1,26 @@
+/*
 
+    File: cramfs.h
+
+    Copyright (C) 2004-2006 Christophe GRENIER <grenier@cgsecurity.org>
+  
+    This software is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+  
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+  
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write the Free Software Foundation, Inc., 51
+    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+
+ */
+/* real size is 76 */
+#define CRAMFS_SUPERBLOCK_SIZE 512
 #define CRAMFS_MAGIC		0x28cd3d45	/* some random number */
 #define CRAMFS_SIGNATURE	"Compressed ROMFS"
 
@@ -59,4 +81,3 @@ struct cramfs_super {
 
 int check_cramfs(t_param_disk *disk_car,t_partition *partition,const int debug);
 int recover_cramfs(t_param_disk *disk_car, const struct cramfs_super *sb,t_partition *partition,const int debug, const int dump_ind);
-
