@@ -247,12 +247,16 @@ static long int dir_aff(t_param_disk *disk_car, const t_partition *partition, t_
     int i;
     int car;
     for(i=0,current_file=dir_list;(current_file!=NULL) && (i<offset);current_file=current_file->next,i++);
+    wmove(dir_data->window, 8-1, 4);
+    wclrtoeol(dir_data->window);
+    if(offset>0)
+      wdoprintf(dir_data->window, "Previous");
     for(i=offset;(current_file!=NULL) &&((i-offset)<INTER_DIR);i++,current_file=current_file->next)
     {
       struct tm		*tm_p;
       char str[11];
       char		datestr[80];
-      wmove(dir_data->window,8+i-offset,0);
+      wmove(dir_data->window, 8+i-offset, 0);
       wclrtoeol(dir_data->window);	/* before addstr for BSD compatibility */
       if(current_file==pos)
 	wattrset(dir_data->window,A_STANDOUT);
@@ -278,7 +282,11 @@ static long int dir_aff(t_param_disk *disk_car, const t_partition *partition, t_
     }
     /* Clear the last line, useful if overlapping */
     wmove(dir_data->window,8+i-offset,0);
-    wclrtoeol(dir_data->window);	/* before addstr for BSD compatibility */
+    wclrtoeol(dir_data->window);
+    wmove(dir_data->window, 8+INTER_DIR, 4);
+    wclrtoeol(dir_data->window);
+    if(current_file!=NULL)
+      wdoprintf(dir_data->window, "Next");
     if(dir_list==NULL)
     {
       wmove(dir_data->window,8,0);
@@ -398,6 +406,7 @@ static long int dir_aff(t_param_disk *disk_car, const t_partition *partition, t_
 	      }
 	      if(dir_data->local_dir!=NULL)
 	      {
+		int res=-1;
 		wmove(dir_data->window,7,0);
 		wclrtoeol(dir_data->window);
 		if(has_colors())
@@ -408,17 +417,29 @@ static long int dir_aff(t_param_disk *disk_car, const t_partition *partition, t_
 		wrefresh(dir_data->window);
 		if(LINUX_S_ISDIR(pos->filestat.st_mode)!=0)
 		{
-		  copy_dir(disk_car, partition, dir_data, (unsigned long int)pos->filestat.st_ino);
+		  res=copy_dir(disk_car, partition, dir_data, (unsigned long int)pos->filestat.st_ino);
 		}
 		else if(LINUX_S_ISREG(pos->filestat.st_mode)!=0)
 		{
-		  dir_data->copy_file(disk_car, partition, dir_data, (unsigned long int)pos->filestat.st_ino);
+		  res=dir_data->copy_file(disk_car, partition, dir_data, (unsigned long int)pos->filestat.st_ino);
 		}
 		wmove(dir_data->window,7,0);
 		wclrtoeol(dir_data->window);
-		if(has_colors())
-		  wbkgdset(dir_data->window,' ' | A_BOLD | COLOR_PAIR(2));
-		wdoprintf(dir_data->window,"Copy done!");
+		if(res<0)
+		{
+		  if(has_colors())
+		    wbkgdset(dir_data->window,' ' | A_BOLD | COLOR_PAIR(1));
+		  wdoprintf(dir_data->window,"Copy failed!");
+		}
+		else
+		{
+		  if(has_colors())
+		    wbkgdset(dir_data->window,' ' | A_BOLD | COLOR_PAIR(2));
+		  if(res>0)
+		    wdoprintf(dir_data->window,"Copy done! (Failed to copy some files)");
+		  else
+		    wdoprintf(dir_data->window,"Copy done!");
+		}
 		if(has_colors())
 		  wbkgdset(dir_data->window,' ' | COLOR_PAIR(0));
 	      }
@@ -503,11 +524,13 @@ static int dir_partition_aux(t_param_disk *disk_car, const t_partition *partitio
 
 static int copy_dir(t_param_disk *disk_car, const t_partition *partition, t_dir_data *dir_data, const unsigned long int inode)
 {
+  unsigned int file_failed=0;
+  unsigned int file_copied=0;
   t_file_data *dir_list;
   unsigned int current_directory_namelength=strlen(dir_data->current_directory);
   t_file_data *current_file;
   if(dir_data->get_dir==NULL || dir_data->copy_file==NULL)
-    return 1;
+    return -1;
   ecrit_rapport("copy_dir %s\n",dir_data->current_directory);
   {
     char *dir_name=MALLOC(strlen(dir_data->local_dir)+strlen(dir_data->current_directory)+1);
@@ -534,13 +557,16 @@ static int copy_dir(t_param_disk *disk_car, const t_partition *partition, t_dir_
       else if(LINUX_S_ISREG(current_file->filestat.st_mode)!=0)
       {
 //	ecrit_rapport("copy_file %s\n",dir_data->current_directory);
-	dir_data->copy_file(disk_car, partition, dir_data, (unsigned long int)current_file->filestat.st_ino);
+	if(dir_data->copy_file(disk_car, partition, dir_data, (unsigned long int)current_file->filestat.st_ino))
+	  file_failed++;
+	else
+	  file_copied++;
       }
       dir_data->current_directory[current_directory_namelength]='\0';
     }
   }
   delete_list_file(dir_list);
-  return 0;
+  return (file_copied>0?(file_failed>0?1:0):-1);
 }
 
 FILE *create_file(const char *filename)
