@@ -55,7 +55,7 @@ void interface_editor(t_param_disk *disk_car)
       { 'Q', "Quit",""},
       { 0, NULL, NULL }
     };
-    switch ( wmenuSelect(stdscr,INTER_DUMP_Y, INTER_DUMP_X, menuEditor, 8, "CDQ", MENU_HORIZ | MENU_BUTTON | MENU_ACCEPT_OTHERS, 0))
+    switch ( wmenuSelect(stdscr,INTER_DUMP_Y, INTER_DUMP_X, menuEditor, 8, "CDQ", MENU_HORIZ | MENU_BUTTON, 0))
     {
       case 'c':
       case 'C':
@@ -130,7 +130,7 @@ static void interface_editor_position(const t_param_disk *disk_car,uint64_t *lba
 	  { 'd', "Done", "Done with changing" },
 	  { 0, NULL, NULL }
 	};
-	wmove(stdscr,COMMAND_LINE_Y, COMMAND_LINE_X);
+	wmove(stdscr,INTER_GEOM_Y, INTER_GEOM_X);
 	wclrtoeol(stdscr);
 	wrefresh(stdscr);
 	command=wmenuSimple(stdscr,menuGeometry, 3);
@@ -138,7 +138,7 @@ static void interface_editor_position(const t_param_disk *disk_car,uint64_t *lba
 	  case 'c':
 	  case 'C':
 		sprintf(def, "%u", position.cylinder);
-		mvwaddstr(stdscr,COMMAND_LINE_Y, COMMAND_LINE_X, "Enter the number of cylinders: ");
+		mvwaddstr(stdscr,INTER_GEOM_Y, INTER_GEOM_X, "Enter the number of cylinders: ");
 		if (get_string(response, LINE_LENGTH, def) > 0) {
 		  tmp_val = atoi(response);
 		  if (tmp_val <= disk_car->CHS.cylinder) {
@@ -150,7 +150,7 @@ static void interface_editor_position(const t_param_disk *disk_car,uint64_t *lba
 	  case 'h':
 	  case 'H':
 		sprintf(def, "%u", position.head);
-		mvwaddstr(stdscr,COMMAND_LINE_Y, COMMAND_LINE_X, "Enter the number of heads: ");
+		mvwaddstr(stdscr,INTER_GEOM_Y, INTER_GEOM_X, "Enter the number of heads: ");
 		if (get_string(response, LINE_LENGTH, def) > 0) {
 		  tmp_val = atoi(response);
 		  if (tmp_val <= disk_car->CHS.head) {
@@ -162,7 +162,7 @@ static void interface_editor_position(const t_param_disk *disk_car,uint64_t *lba
 	  case 's':
 	  case 'S':
 		sprintf(def, "%u", position.sector);
-		mvwaddstr(stdscr,COMMAND_LINE_Y, COMMAND_LINE_X, "Enter the number of sectors per track: ");
+		mvwaddstr(stdscr,INTER_GEOM_Y, INTER_GEOM_X, "Enter the number of sectors per track: ");
 		if (get_string(response, LINE_LENGTH, def) > 0) {
 		  tmp_val = atoi(response);
 		  if (tmp_val > 0 && tmp_val <= disk_car->CHS.sector ) {
