@@ -361,7 +361,7 @@ unsigned int get_next_cluster(t_param_disk *disk_car,const t_partition *partitio
     case UP_FAT16:
       {
 	unsigned char buffer[disk_car->sector_size];
-	uint16_t *p16=(uint16_t*)&buffer;
+	const uint16_t *p16=(const uint16_t*)&buffer;
 	unsigned long int offset_s,offset_o;
 	offset_s=cluster/(disk_car->sector_size/2);
 	offset_o=cluster%(disk_car->sector_size/2);
@@ -374,8 +374,9 @@ unsigned int get_next_cluster(t_param_disk *disk_car,const t_partition *partitio
     case UP_FAT32:
       {
 	unsigned char buffer[disk_car->sector_size];
-	uint32_t *p32=(uint32_t*)&buffer;
+	const uint32_t *p32;
 	unsigned long int offset_s,offset_o;
+	p32=(const uint32_t*)&buffer;
 	offset_s=cluster/(disk_car->sector_size/4);
 	offset_o=cluster%(disk_car->sector_size/4);
 	if(disk_car->read(disk_car,disk_car->sector_size, &buffer, partition->part_offset+(uint64_t)(offset+offset_s)*disk_car->sector_size)!=0)
@@ -462,9 +463,11 @@ int set_next_cluster(t_param_disk *disk_car,const t_partition *partition, const
 unsigned int fat32_get_prev_cluster(t_param_disk *disk_car,const t_partition *partition, const unsigned int fat_offset, const unsigned int cluster, const unsigned int no_of_cluster)
 {
   unsigned char buffer[disk_car->sector_size];
-  uint32_t *p32=(uint32_t*)&buffer;
+  const uint32_t *p32;
   uint64_t hd_offset=partition->part_offset+fat_offset*disk_car->sector_size;
   unsigned int prev_cluster;
+  p32=(const uint32_t*)&buffer;
+
   for(prev_cluster=2;prev_cluster<=no_of_cluster+1;prev_cluster++)
   {
     unsigned int offset_s,offset_o;
@@ -1062,11 +1065,11 @@ int is_fat32(const t_partition *partition)
 int fat32_free_info(t_param_disk *disk_car,const t_partition *partition, const unsigned int fat_offset, const unsigned int no_of_cluster, unsigned int *next_free, unsigned int*free_count)
 {
   unsigned char *buffer;
-  uint32_t *p32;
+  const uint32_t *p32;
   unsigned int prev_cluster;
   uint64_t hd_offset=partition->part_offset+(uint64_t)fat_offset*disk_car->sector_size;
   buffer=(unsigned char *)MALLOC(disk_car->sector_size);
-  p32=(uint32_t*)buffer;
+  p32=(const uint32_t*)buffer;
   *next_free=0;
   *free_count=0;
   for(prev_cluster=2;prev_cluster<=no_of_cluster+1;prev_cluster++)
