@@ -48,6 +48,8 @@
 #include "dirpart.h"
 #include "fat_dir.h"
 #include "io_redir.h"
+#define INTER_FAT_ASK_X 0
+#define INTER_FAT_ASK_Y	23
 static const char *monstr[] = { "Jan", "Feb", "Mar", "Apr", "May", "Jun",
 				"Jul", "Aug", "Sep", "Oct", "Nov", "Dec"};
 
@@ -993,7 +995,7 @@ static int create_fat_boot_sector(t_param_disk *disk_car, t_partition *partition
       newboot[disk_car->sector_size+0x1E9]=0xFF;
       newboot[disk_car->sector_size+0x1EA]=0xFF;
       newboot[disk_car->sector_size+0x1EB]=0xFF;
-      newboot[disk_car->sector_size+0x1EC]=0xFF;	/* 492: Next avaible clusters */
+      newboot[disk_car->sector_size+0x1EC]=0xFF;	/* 492: Next available clusters */
       newboot[disk_car->sector_size+0x1ED]=0xFF;
       newboot[disk_car->sector_size+0x1EE]=0xFF;
       newboot[disk_car->sector_size+0x1EF]=0xFF;
@@ -1594,7 +1596,7 @@ static upart_type_t fat_find_info(t_param_disk *disk_car,unsigned int*reserved,
     unsigned int first_fat=0;
     unsigned int second_fat=0;
     /* select the good type in the 3 first possibilities */
-    for(i=0;i<nbr_offset && i<3;i++)
+    for(i=0;i<nbr_offset && (i<3 || info_offset[i].offset<=33);i++)
     {
       if(info_offset[i].nbr>info_offset[offset_for_max_nbr].nbr)
 	offset_for_max_nbr=i;
@@ -1719,14 +1721,16 @@ static upart_type_t select_fat_info(const t_info_offset *info_offset, const unsi
   aff_copy(stdscr);
   wmove(stdscr,4,0);
   screen_buffer_display(stdscr,"",menuSelectFAT);
-  wmove(stdscr,23,0);
+  wmove(stdscr,INTER_FAT_ASK_Y, INTER_FAT_ASK_X);
   *reserved=ask_number(*reserved,0,max_sector_offset,"FAT1 location (Number of reserved sector) ");
   if(*reserved>0)
   {
+    wmove(stdscr,INTER_FAT_ASK_Y, INTER_FAT_ASK_X);
     fat2_location=ask_number(fat2_location,0,max_sector_offset,"FAT2 location ");
     if(fat2_location>*reserved)
     {
       *fat_length=fat2_location-*reserved;
+      wmove(stdscr,INTER_FAT_ASK_Y, INTER_FAT_ASK_X);
       *fats=ask_number(*fats,1,2,"Number of FATS (Usually 2) ");
     }
     else
@@ -2190,6 +2194,7 @@ int rebuild_FAT_BS(t_param_disk *disk_car, t_partition *partition, const int deb
       }
       if(expert>0)
       {
+	wmove(stdscr, INTER_FAT_ASK_Y, INTER_FAT_ASK_X);
 	cluster_size=ask_number(cluster_size,0,128,"cluster size ");
 	switch(cluster_size)
 	{
@@ -2221,6 +2226,7 @@ int rebuild_FAT_BS(t_param_disk *disk_car, t_partition *partition, const int deb
       root_cluster=fat32_find_root_cluster(disk_car,partition,cluster_size,data_size/cluster_size,reserved,fat_length,interface,debug,expert,first_free_cluster,fats);
       if(expert>0)
       {
+	wmove(stdscr, INTER_FAT_ASK_Y, INTER_FAT_ASK_X);
 	root_cluster=ask_number(root_cluster,2,data_size/cluster_size+1,"root cluster ");
 	if(debug>1)
 	{
@@ -2796,7 +2802,7 @@ int repair_FAT_table(t_param_disk *disk_car, t_partition *partition, const int d
     }
     if(fat_damaged==0)
     {
-      display_message("FATs seems Ok, nothing to do.");
+      display_message("FATs seems Ok, nothing to do.\n");
     }
     delwin(window);
     (void) clearok(stdscr, TRUE);
