@@ -37,7 +37,7 @@
 
 static void file_check_doc(t_file_recovery *file_recovery);
 static const char* header_check_doc(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
-static const unsigned char * find_in_mem(const unsigned char *haystack, const unsigned char *needle, const unsigned int haystack_size);
+static const unsigned char * find_in_mem(const unsigned char *haystack, const unsigned int haystack_size, const unsigned char *needle, const unsigned int needle_size);
 static uint64_t test_OLE(FILE *file);
 
 const t_file_hint file_hint_doc= {
@@ -52,10 +52,9 @@ const t_file_hint file_hint_doc= {
   .file_check=&file_check_doc
 };
 
-static const unsigned char * find_in_mem(const unsigned char *haystack, const unsigned char *needle, const unsigned int haystack_size)
+static const unsigned char * find_in_mem(const unsigned char *haystack, const unsigned int haystack_size, const unsigned char *needle, const unsigned int needle_size)
 {
   unsigned int i;
-  unsigned int needle_size=strlen(needle);
   for(i=0;i<haystack_size-needle_size;i++)
     if(memcmp(&haystack[i],needle,needle_size)==0)
       return &haystack[i];
@@ -89,47 +88,51 @@ static const char* header_check_doc(const unsigned char *buffer, const unsigned
 	le32(header->num_FAT_blocks)>109+le32(header->num_extra_FAT_blocks)*((1<<le16(header->uSectorShift))-1))
       return NULL;
     /* TODO read the Root Directory */
-    if(find_in_mem(buffer,"WordDocument",buffer_size)!=NULL)
+    if(find_in_mem(buffer,buffer_size,"WordDocument",12)!=NULL)
     {
       return "doc";
     }
-    else if(find_in_mem(buffer,"StarDraw",buffer_size)!=NULL)
+    else if(find_in_mem(buffer,buffer_size,"StarDraw",8)!=NULL)
     {
       return "sda";
     }
-    else if(find_in_mem(buffer,"StarCalc",buffer_size)!=NULL)
+    else if(find_in_mem(buffer,buffer_size,"StarCalc",8)!=NULL)
     {
       return "sdc";
     }
-    else if(find_in_mem(buffer,"StarImpress",buffer_size)!=NULL)
+    else if(find_in_mem(buffer,buffer_size,"StarImpress",11)!=NULL)
     {
       return "sdd";
     }
-    else if(find_in_mem(buffer,"Worksheet",buffer_size)!=NULL || find_in_mem(buffer,"Book",buffer_size)!=NULL || find_in_mem(buffer,"Workbook",buffer_size)!=NULL || find_in_mem(buffer,"Calc",buffer_size)!=NULL)
+    else if(find_in_mem(buffer,buffer_size,"Worksheet",9)!=NULL ||
+	find_in_mem(buffer,buffer_size,"Book",4)!=NULL || 
+	find_in_mem(buffer,buffer_size,"Workbook",8)!=NULL || 
+	find_in_mem(buffer,buffer_size,"W\0o\0r\0k\0b\0o\0o\0k\0",16)!=NULL || 
+	find_in_mem(buffer,buffer_size,"Calc",4)!=NULL)
     {
       return "xls";
     }
-    else if(find_in_mem(buffer,"Power",buffer_size)!=NULL)
+    else if(find_in_mem(buffer,buffer_size,"Power",5)!=NULL)
     {
       return "ppt";
     }
-    else if(find_in_mem(buffer,"AccessObjSiteData",buffer_size)!=NULL)
+    else if(find_in_mem(buffer,buffer_size,"AccessObjSiteData",17)!=NULL)
     {
       return "mdb";
     }
-    else if(find_in_mem(buffer,"Visio",buffer_size)!=NULL)
+    else if(find_in_mem(buffer,buffer_size,"Visio",5)!=NULL)
     {
       return "vis";
     }
-    else if(find_in_mem(buffer,"Sfx",buffer_size)!=NULL)
+    else if(find_in_mem(buffer,buffer_size,"Sfx",3)!=NULL)
     {
       return "sdw";
     }
-    else if(find_in_mem(buffer,"CPicPage",buffer_size)!=NULL)
+    else if(find_in_mem(buffer,buffer_size,"CPicPage",8)!=NULL)
     {	/* Flash */
       return "fla";
     }
-    else  if(find_in_mem(buffer,"Microsoft Publisher",buffer_size)!=NULL)
+    else  if(find_in_mem(buffer,buffer_size,"Microsoft Publisher",19)!=NULL)
     {
       return "pub";
     }
