@@ -34,7 +34,7 @@
 static const char* header_check_eps(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
 const t_file_hint file_hint_eps= {
   .extension="eps",
-  .description="Encasulated PostScript",
+  .description="Encapsulated PostScript",
   .min_header_distance=0,
   .min_filesize=0,
   .max_filesize=PHOTOREC_MAX_FILE_SIZE,
