@@ -15,8 +15,8 @@
     GNU General Public License for more details.
   
     You should have received a copy of the GNU General Public License along
-    with this program; if not, write the Free Software Foundation, Inc., 59
-    Temple Place - Suite 330, Boston MA 02111-1307, USA.
+    with this program; if not, write the Free Software Foundation, Inc., 51
+    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  */
 
@@ -26,6 +26,7 @@
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
+#include <stdio.h>
 #include "types.h"
 #include "common.h"
 #include "ext2.h"
