@@ -2,7 +2,7 @@
 
     File: file_jpg.c
 
-    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@
 static const char* header_check_jpg(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery);
 static void file_check_jpg(t_file_recovery *file_recovery);
 
-const t_file_hint file_hint_jpg= {
+t_file_hint file_hint_jpg= {
   .extension="jpg",
   .description="JPG picture",
   .min_header_distance=0,
@@ -53,11 +53,33 @@ const t_file_hint file_hint_jpg= {
 };
 static const char* header_check_jpg(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
 {
-  const unsigned char jpg_header[4]= { 0xff,0xd8,0xff,0xe1};
-  const unsigned char jpg2_header[4]= { 0xff,0xd8,0xff,0xe0};
-  if((memcmp(buffer,jpg_header,sizeof(jpg_header))==0)
-      ||(memcmp(buffer,jpg2_header,sizeof(jpg2_header))==0))
+  const unsigned char jpg_header_app0[4]= { 0xff,0xd8,0xff,0xe0};
+  const unsigned char jpg_header_app1[4]= { 0xff,0xd8,0xff,0xe1};
+  if(memcmp(buffer,jpg_header_app0,sizeof(jpg_header_app0))==0 ||
+      memcmp(buffer,jpg_header_app1,sizeof(jpg_header_app1))==0)
+  {
+    unsigned int i=2;
+    do
+    {
+      if(buffer[i]==0xff && buffer[i+1]==0xe0)
+      { /* APP0 */
+	i+=2+(buffer[i+2]<<8)+buffer[i+3];
+      }
+      else if(buffer[i]==0xff && buffer[i+1]==0xe1)
+      { /* APP1 Exif information */
+	i+=2+(buffer[i+2]<<8)+buffer[i+3];
+      }
+      else
+      {
+	file_hint_jpg.min_filesize=288;
+//	ecrit_rapport("jpg min_filesize=%lu\n", (unsigned long) file_hint_jpg.min_filesize);
+	return file_hint_jpg.extension;
+      }
+    } while(i<6*512 && i<buffer_size);
+    file_hint_jpg.min_filesize=i;
+ //   ecrit_rapport("jpg min_filesize=%lu\n", (unsigned long) file_hint_jpg.min_filesize);
     return file_hint_jpg.extension;
+  }
   return NULL;
 }
 
@@ -67,7 +89,7 @@ static void file_check_jpg(t_file_recovery *file_recovery)
   file_recovery->file_size=(jpg_file_size>0?jpg_file_size:0);
 }
 
-#ifdef HAVE_LIBJPEG
+#if defined(HAVE_LIBJPEG) && defined(HAVE_JPEGLIB_H)
 struct my_error_mgr {
   struct jpeg_error_mgr pub;	/* "public" fields */
 
@@ -104,7 +126,7 @@ static void my_error_exit (j_common_ptr cinfo)
 int64_t test_jpeg(FILE *infile)
 {
   uint64_t jpeg_size=0;
-#ifdef HAVE_LIBJPEG
+#if defined(HAVE_LIBJPEG) && defined(HAVE_JPEGLIB_H)
   struct my_error_mgr jerr;
   {
     struct jpeg_decompress_struct cinfo;
@@ -146,7 +168,7 @@ int64_t test_jpeg(FILE *infile)
   }
 #endif
   jpeg_size=ftell(infile);
-#ifdef HAVE_LIBJPEG
+#if defined(HAVE_LIBJPEG) && defined(HAVE_JPEGLIB_H)
   if(jerr.pub.num_warnings>0)
   {
     /* Not accurate */
