@@ -39,7 +39,7 @@ static unsigned int frame_offset=0;
 
 const t_file_hint file_hint_mov= {
   .extension="mov",
-  .description="MOV video",
+  .description="mov/mp4/3gp/3g2/jp2",
   .min_header_distance=0,
   .min_filesize=0,
   .max_filesize=PHOTOREC_MAX_FILE_SIZE,
@@ -53,11 +53,11 @@ const t_file_hint file_hint_mov= {
   .file_check=NULL
 };
 
-static const unsigned char * find_in_mem(const unsigned char *haystack, const unsigned char *needle, const unsigned int haystack_size);
-static const unsigned char * find_in_mem(const unsigned char *haystack, const unsigned char *needle, const unsigned int haystack_size)
+static const unsigned char * find_in_mem(const unsigned char *haystack, const unsigned int haystack_size, const unsigned char *needle, const unsigned int needle_size);
+
+static const unsigned char * find_in_mem(const unsigned char *haystack, const unsigned int haystack_size, const unsigned char *needle, const unsigned int needle_size)
 {
   unsigned int i;
-  unsigned int needle_size=strlen(needle);
   for(i=0;i<haystack_size-needle_size;i++)
     if(memcmp(&haystack[i],needle,needle_size)==0)
       return &haystack[i];
@@ -108,18 +108,21 @@ static const char* header_check_mov(const unsigned char *buffer, const unsigned
     {
       if(atom_size>buffer_size-offset)
 	atom_size=buffer_size-offset;
-      if(find_in_mem(&buffer[offset+8], "isom",atom_size-8)!=NULL ||
-	  find_in_mem(&buffer[offset+8], "mp41",atom_size-8)!=NULL ||
-	  find_in_mem(&buffer[offset+8], "mp42",atom_size-8)!=NULL ||
-	  find_in_mem(&buffer[offset+8], "3gp",atom_size-8)!=NULL ||
-	  find_in_mem(&buffer[offset+8], "mmp4",atom_size-8)!=NULL ||
-	  find_in_mem(&buffer[offset+8], "M4A",atom_size-8)!=NULL ||
-	  find_in_mem(&buffer[offset+8], "M4P",atom_size-8)!=NULL ||
-	  find_in_mem(&buffer[offset+8], "M4B",atom_size-8)!=NULL)
+      if(find_in_mem(&buffer[offset+8], atom_size-8, "isom", 4)!=NULL ||
+	  find_in_mem(&buffer[offset+8], atom_size-8, "mp41", 4)!=NULL ||
+	  find_in_mem(&buffer[offset+8], atom_size-8, "mp42", 4)!=NULL ||
+	  find_in_mem(&buffer[offset+8], atom_size-8, "mmp4", 4)!=NULL ||
+	  find_in_mem(&buffer[offset+8], atom_size-8, "M4A", 3)!=NULL ||
+	  find_in_mem(&buffer[offset+8], atom_size-8, "M4B", 3)!=NULL ||
+	  find_in_mem(&buffer[offset+8], atom_size-8, "M4P", 3)!=NULL)
 	return "mp4";
-      if(find_in_mem(&buffer[offset+8], "jp2",atom_size-8)!=NULL)
+      if(find_in_mem(&buffer[offset+8], atom_size-8, "3gp", 3)!=NULL)
+	return "3gp";
+      if(find_in_mem(&buffer[offset+8], atom_size-8, "3g2", 3)!=NULL)
+	return "3g2";
+      if(find_in_mem(&buffer[offset+8], atom_size-8, "jp2", 3)!=NULL)
 	return "jp2";
-      if(find_in_mem(&buffer[offset+8], "qt",atom_size-8)!=NULL)
+      if(find_in_mem(&buffer[offset+8], atom_size-8, "qt", 2)!=NULL)
 	return "mov";
     }
     if(prev_atom_skip==1 && buffer[offset+4]=='m' && buffer[offset+5]=='d' && buffer[offset+6]=='a' && buffer[offset+7]=='t')
