@@ -57,7 +57,7 @@ static const char* header_check_pcx(const unsigned char *buffer, const unsigned
   buffer[3]	Number of bits of color used for each pixel
   */
   if(buffer[0]==0x0a && (buffer[1]<=5 && buffer[1]!=1) && buffer[2]<=1 &&
-    (buffer[3]==1 || buffer[3]==4 || buffer[3]==8 || buffer[3]==16 || buffer[3]==24))
+    (buffer[3]==1 || buffer[3]==4 || buffer[3]==8 || buffer[3]==24))
     return file_hint_pcx.extension;
   return NULL;
 }
