@@ -36,7 +36,7 @@ static void file_check_pdf(t_file_recovery *file_recovery);
 
 const t_file_hint file_hint_pdf= {
   .extension="pdf",
-  .description="Portable Document Format",
+  .description="Portable Document Format, Adobe Illustrator",
   .min_header_distance=0,
   .min_filesize=0,
   .max_filesize=PHOTOREC_MAX_FILE_SIZE,
@@ -45,12 +45,39 @@ const t_file_hint file_hint_pdf= {
   .data_check=NULL,
   .file_check=&file_check_pdf
 };
+static inline const unsigned char *find_in_mem(const unsigned char *haystack, const unsigned char * haystack_end,
+    const unsigned char *needle, const unsigned int needle_length);
+
+static inline const unsigned char *find_in_mem(const unsigned char *haystack, const unsigned char * haystack_end,
+    const unsigned char *needle, const unsigned int needle_length)
+{
+  while(haystack!=NULL)
+  {
+    haystack=memchr(haystack,needle[0],haystack_end-haystack);
+    if(haystack!=NULL && haystack<=(haystack_end-needle_length))
+    {
+      if(memcmp(haystack,needle,needle_length)==0)
+	return haystack;
+      haystack++;
+    }
+    else
+      haystack=NULL;
+  };
+  return NULL;
+}
 
 static const char* header_check_pdf(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only,  t_file_recovery *file_recovery)
 {
   const unsigned char pdf_header[]  = { '%','P','D','F','-','1'};
   if(memcmp(buffer,pdf_header,sizeof(pdf_header))==0)
+  {
+    const unsigned char sig_illustrator[11]={'I','l','l','u','s','t','r','a','t','o','r'};
+    if(find_in_mem(buffer, buffer+512, sig_illustrator,sizeof(sig_illustrator)) != NULL)
+    {
+      return "ai";
+    }
     return file_hint_pdf.extension;
+  }
   return NULL;
 }
 
