@@ -34,7 +34,7 @@ static const char* header_check_pst(const unsigned char *buffer, const unsigned
 
 const t_file_hint file_hint_pst= {
   .extension="pst",
-  .description="Outlook",
+  .description="Outlook (pst/wab/dbx)",
   .min_header_distance=0,
   .min_filesize=16,
   .max_filesize=PHOTOREC_MAX_FILE_SIZE,
