@@ -50,6 +50,8 @@ static const char* header_check_riff(const unsigned char *buffer, const unsigned
       return "wav";
     if(memcmp(&buffer[8],"CDR",3)==0)
       return "cdr";
+    if(memcmp(&buffer[8],"NUND",4)==0)
+      return "cpr";
     return "avi";
   }
   return NULL;
