@@ -34,7 +34,7 @@ static const char* header_check_sit(const unsigned char *buffer, const unsigned
 
 const t_file_hint file_hint_sit= {
   .extension="sit",
-  .description="Mikron",
+  .description="Mikron image",
   .min_header_distance=0,
   .min_filesize=0,
   .max_filesize=PHOTOREC_MAX_FILE_SIZE,
