@@ -15,8 +15,8 @@
     GNU General Public License for more details.
   
     You should have received a copy of the GNU General Public License along
-    with this program; if not, write the Free Software Foundation, Inc., 59
-    Temple Place - Suite 330, Boston MA 02111-1307, USA.
+    with this program; if not, write the Free Software Foundation, Inc., 51
+    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  */
 
@@ -26,6 +26,7 @@
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
+#include <stdio.h>
 #include "types.h"
 #include "photorec.h"
 
@@ -105,32 +106,8 @@ static const char* header_check_tiff(const unsigned char *buffer, const unsigned
 // Seems to be wrong
 static void file_check_tiff(t_file_recovery *file_recovery)
 {
-  int64_t tiff_file_size=test_tiff(file_recovery->handle);
-  file_recovery->file_size=(tiff_file_size>0?tiff_file_size:0);
-}
+  const unsigned char tiff_footer[2]= {0xff, 0xd9};
+  file_search_footer(file_recovery, tiff_footer,sizeof(tiff_footer));
 
-static int64_t test_tiff(FILE *infile)
-{
-  unsigned char buffer[0x2000];
-  uint64_t file_size=ftell(infile);
-  int back=(file_size<sizeof(buffer)/2?file_size:sizeof(buffer)/2);
-  do
-  {
-    int i;
-    for(i=sizeof(buffer)-back-1;i>=0;i--)
-      buffer[i+back]=buffer[i];
-    if(fseek(infile,file_size-back,SEEK_SET)>=0)
-    {
-      fread(buffer,1,back,infile);
-      for(i=back-1;i>=0;i--)
-      {
-	if(buffer[i]==0xFF && buffer[i+1]==0xD9)
-	  return file_size-back+i+2;
-      }
-    }
-    file_size=file_size-back;
-    back=(file_size<sizeof(buffer)/2?file_size:sizeof(buffer)/2);
-  } while(back>0);
-  return 0;
 }
 */
