@@ -63,14 +63,14 @@ void change_geometry(t_param_disk *disk_car, char ** current_cmd)
     wmove(stdscr,8,0);
     wdoprintf(stdscr,"and calculates their sizes, it's important to have the correct disk geometry.");
     wmove(stdscr,9,0);
-    wdoprintf(stdscr,"PC partitionning programs often make partitions end on cylinder boundaries.");
+    wdoprintf(stdscr,"PC partitioning programs often make partitions end on cylinder boundaries.");
     wmove(stdscr,11,0);
     wdoprintf(stdscr,"A partition's CHS values are based on disk translations which make them");
     wmove(stdscr,12,0);
     wdoprintf(stdscr,"different than its physical geometry. The most common CHS head values");
     wmove(stdscr,13,0);
     wdoprintf(stdscr,"are: 255, 240 and sometimes 16.");
-    wmove(stdscr,COMMAND_LINE_Y, COMMAND_LINE_X);
+    wmove(stdscr,INTER_GEOM_Y, INTER_GEOM_X);
     wclrtoeol(stdscr);
     wrefresh(stdscr);
     if(*current_cmd!=NULL)
@@ -110,7 +110,7 @@ void change_geometry(t_param_disk *disk_car, char ** current_cmd)
 	{
 	  int ok=0;
 	  sprintf(def, "%u", disk_car->CHS.cylinder+1);
-	  mvwaddstr(stdscr,COMMAND_LINE_Y, COMMAND_LINE_X, "Enter the number of cylinders: ");
+	  mvwaddstr(stdscr,INTER_GEOM_Y, INTER_GEOM_X, "Enter the number of cylinders: ");
 	  if(*current_cmd!=NULL)
 	  {
 	    while(*current_cmd[0]==',')
@@ -143,7 +143,7 @@ void change_geometry(t_param_disk *disk_car, char ** current_cmd)
 	{
 	  int ok=0;
 	  sprintf(def, "%u", disk_car->CHS.head+1);
-	  mvwaddstr(stdscr,COMMAND_LINE_Y, COMMAND_LINE_X, "Enter the number of heads: ");
+	  mvwaddstr(stdscr,INTER_GEOM_Y, INTER_GEOM_X, "Enter the number of heads: ");
 	  if(*current_cmd!=NULL)
 	  {
 	    while(*current_cmd[0]==',')
@@ -179,7 +179,7 @@ void change_geometry(t_param_disk *disk_car, char ** current_cmd)
 	{
 	  int ok=0;
 	  sprintf(def, "%u", disk_car->CHS.sector);
-	  mvwaddstr(stdscr,COMMAND_LINE_Y, COMMAND_LINE_X, "Enter the number of sectors per track (1-63): ");
+	  mvwaddstr(stdscr,INTER_GEOM_Y, INTER_GEOM_X, "Enter the number of sectors per track (1-63): ");
 	  if(*current_cmd!=NULL)
 	  {
 	    while(*current_cmd[0]==',')
@@ -216,7 +216,7 @@ void change_geometry(t_param_disk *disk_car, char ** current_cmd)
 	{
 	  int ok=0;
 	  sprintf(def, "%u", disk_car->sector_size);
-	  mvwaddstr(stdscr,COMMAND_LINE_Y, COMMAND_LINE_X, "Enter the sector size (512, 1024, 2048, 4096): ");
+	  mvwaddstr(stdscr,INTER_GEOM_Y, INTER_GEOM_X, "Enter the sector size (512, 1024, 2048, 4096): ");
 	  if(*current_cmd!=NULL)
 	  {
 	    while(*current_cmd[0]==',')
