@@ -60,6 +60,7 @@ static unsigned int tab_insert(uint64_t *tab, uint64_t offset, unsigned int tab_
 /* Optimization */
 static inline void offset2CHS_inline(const t_param_disk *disk_car,const uint64_t offset, t_CHS*CHS);
 static inline uint64_t CHS2offset_inline(const t_param_disk *disk_car,const t_CHS*CHS);
+static t_list_part *search_part(t_param_disk *disk_car, const t_list_part *list_part_org, const int debug, const int dump_ind, const int fast_mode, const int interface);
 
 static inline void offset2CHS_inline(const t_param_disk *disk_car,const uint64_t offset, t_CHS*CHS)
 {
@@ -389,7 +390,7 @@ static unsigned int tab_insert(uint64_t *tab, uint64_t offset, unsigned int tab_
    - Geometry: don't care
 */
 
-t_list_part *search_part(t_param_disk *disk_car, const int debug, const int dump_ind, const int fast_mode, const int interface)
+static t_list_part *search_part(t_param_disk *disk_car, const t_list_part *list_part_org, const int debug, const int dump_ind, const int fast_mode, const int interface)
 {
   unsigned char *buffer_disk;
   /* TODO use circular buffer for try_offset and try_offset_raid */
@@ -404,6 +405,15 @@ t_list_part *search_part(t_param_disk *disk_car, const int debug, const int dump
   t_partition *partition=partition_new();
   buffer_disk=(unsigned char*)MALLOC(16*DEFAULT_SECTOR_SIZE);
 
+  {
+    /* Will search for partition at current known partition location */
+    const t_list_part *element;
+    for(element=list_part_org;element!=NULL;element=element->next)
+    {
+      try_offset_nbr=tab_insert(try_offset,element->part->part_offset,try_offset_nbr);
+    }
+  }
+
   if(interface!=0)
   {
     wmove(stdscr,22,0);
@@ -724,7 +734,7 @@ static void ask_mbr_order_i386(t_param_disk *disk_car,t_list_part *list_part)
       table[nbr_prim++]=element->part;
   }
   /* */
-  ecrit_rapport("\nSelection des partitions primaires\n");
+  ecrit_rapport("\nSelect primaries partition\n");
   for(i=0;i<nbr_prim;i++)
       aff_part_rapport(disk_car,table[i]);
   /* */
@@ -1023,10 +1033,10 @@ static int use_backup(t_param_disk *disk_car, const t_list_part *list_part, cons
   return 0;
 }
 
-int interface_recovery(t_param_disk *disk_car, const int debug, const int dump_ind, const int align, const int ask_part_order, const unsigned int expert, char **current_cmd)
+int interface_recovery(t_param_disk *disk_car, const t_list_part * list_part_org, const int debug, const int dump_ind, const int align, const int ask_part_order, const unsigned int expert, char **current_cmd)
 {
   int res_interface_write;
-  int menu=-1;
+  unsigned int menu=0;
   int fast_mode=0;
   do
   {
@@ -1037,7 +1047,7 @@ int interface_recovery(t_param_disk *disk_car, const int debug, const int dump_i
     wdoprintf(stdscr,"%s",disk_car->description(disk_car));
     wmove(stdscr,5,0);
     res_interface_write=0;
-    list_part=search_part(disk_car,debug,dump_ind,fast_mode,1);
+    list_part=search_part(disk_car, list_part_org, debug, dump_ind, fast_mode, 1);
     if(list_part!=NULL)
     {
       unsigned int head_max;
@@ -1170,7 +1180,7 @@ int interface_recovery(t_param_disk *disk_car, const int debug, const int dump_i
     }
     else
     {
-      display_message("Invalid partition structure");
+      display_message("Invalid partition structure.\n");
     }
     delete_list_part(list_part);
   } while(res_interface_write=='S');
