@@ -21,6 +21,5 @@
  */
 enum part_offset { PART_OFFSET128, PART_OFFSET2, PART_OFFSET1, PART_OFFSET0, PART_QUIT};
 typedef enum part_offset part_offset_t;
-int interface_recovery(t_param_disk *disk_car, const int debug, const int dump_ind, const int align,const int ask_part_order, const unsigned int expert, char **current_cmd);
+int interface_recovery(t_param_disk *disk_car, const t_list_part * list_part_org, const int debug, const int dump_ind, const int align, const int ask_part_order, const unsigned int expert, char **current_cmd);
 void only_one_bootable( t_list_part *list_part, t_list_part *part_boot);
-t_list_part *search_part(t_param_disk *disk_car, const int debug, const int dump_ind, const int fast_mode, const int interface);
