@@ -102,6 +102,8 @@
 #ifndef O_BINARY
 #define O_BINARY 0
 #endif
+#include "ewf.h"
+
 extern const t_arch_fnct arch_mac;
 
 struct info_file_struct
@@ -648,6 +650,7 @@ t_list_disk *hd_parse(t_list_disk *list_disk, const int debug, const t_arch_fnct
   }
 #elif defined(__CYGWIN__)
   {
+    char device_hd[]="\\\\.\\PhysicalDrive0";
     char device_scsi[]="/dev/sda";
     char device_cdrom[]="\\\\.\\C:";
     /* Disk */
@@ -656,6 +659,32 @@ t_list_disk *hd_parse(t_list_disk *list_disk, const int debug, const t_arch_fnct
       device_scsi[strlen(device_scsi)-1]='a'+i;
       list_disk=insert_new_disk(list_disk,file_test_availability(device_scsi,debug,arch,testdisk_mode));
     }
+    /* Disk */
+    if(list_disk==NULL)
+    {
+      for(i=0;i<8;i++)
+      {
+	device_hd[strlen(device_hd)-1]='0'+i;
+	list_disk=insert_new_disk(list_disk,file_test_availability_win32(device_hd,debug,arch,testdisk_mode));
+      }
+    }
+    /* cdrom */
+    for(i='C';i<='Z';i++)
+    {
+      device_cdrom[strlen(device_cdrom)-2]=i;
+      list_disk=insert_new_disk(list_disk,file_test_availability_win32(device_cdrom,debug,arch,testdisk_mode));
+    }
+  }
+#elif defined(__MINGW32__)
+  {
+    char device_hd[]="\\\\.\\PhysicalDrive0";
+    char device_cdrom[]="\\\\.\\C:";
+    /* Disk */
+    for(i=0;i<8;i++)
+    {
+      device_hd[strlen(device_hd)-1]='0'+i;
+      list_disk=insert_new_disk(list_disk,file_test_availability(device_hd,debug,arch,testdisk_mode));
+    }
     /* cdrom */
     for(i='C';i<='Z';i++)
     {
@@ -679,14 +708,6 @@ t_list_disk *hd_parse(t_list_disk *list_disk, const int debug, const t_arch_fnct
       list_disk=insert_new_disk(list_disk,file_test_availability(device_raw,debug,arch,testdisk_mode));
     }
   }
-#elif defined(__MINGW32__)
-    char device_hd[]="\\\\.\\PhysicalDrive0";
-    /* Disk */
-    for(i=0;i<8;i++)
-    {
-      device_hd[strlen(device_hd)-1]='0'+i;
-      list_disk=insert_new_disk(list_disk,file_test_availability(device_hd,debug,arch,testdisk_mode));
-    }
 #elif defined(TARGET_LINUX)
   {
     int j;
@@ -857,7 +878,10 @@ static t_param_disk *disk_get_geometry_win32(HANDLE handle, const char *device,
     disk_car->disk_size=(uint64_t)(disk_car->CHS.cylinder+1)*(disk_car->CHS.head+1)*disk_car->CHS.sector*disk_car->sector_size;
     disk_car->disk_real_size=disk_car->disk_size;
     if(debug>1)
+    {
       ecrit_rapport("disk_get_geometry_win32(%s) ok\n",device);
+      ecrit_rapport("CHS (%u, %u, %u), sector_size=%u\n", disk_car->CHS.cylinder+1, disk_car->CHS.head+1, disk_car->CHS.sector, disk_car->sector_size);
+    }
   }
   else
   {
@@ -1239,7 +1263,7 @@ static int file_read(t_param_disk *disk_car,const unsigned int count, void *nom_
     return 0;
   }
   {
-    long int ret;
+    long int ret=-1;
 #ifdef DEBUG
       ecrit_rapport("file_read(%d,%u,buffer,%lu(%u/%u/%u))\n", data->handle,
 	  (unsigned)(count/disk_car->sector_size), (long unsigned int)(offset/disk_car->sector_size),
@@ -1247,40 +1271,44 @@ static int file_read(t_param_disk *disk_car,const unsigned int count, void *nom_
 #endif
 #ifdef HAVE_PREAD
       ret=pread(data->handle,nom_buffer,count,offset+data->offset);
-#else
+      if(ret<0 && errno == ENOSYS)
+#endif
+      {
 #ifdef __MINGW32__
-    if(_lseeki64(data->handle,offset+data->offset,SEEK_SET)==-1)
-    {
-      ecrit_rapport("file_read(%d,%u,buffer,%lu(%u/%u/%u)) seek err %s\n", data->handle,
-	  (unsigned)(count/disk_car->sector_size), (long unsigned int)(offset/disk_car->sector_size),
-	  offset2cylinder(disk_car,offset), offset2head(disk_car,offset), offset2sector(disk_car,offset),
-	  strerror(errno));
-      return -1;
-    }
+	if(_lseeki64(data->handle,offset+data->offset,SEEK_SET)==-1)
+	{
+	  ecrit_rapport("file_read(%d,%u,buffer,%lu(%u/%u/%u)) seek err %s\n", data->handle,
+	      (unsigned)(count/disk_car->sector_size), (long unsigned int)(offset/disk_car->sector_size),
+	      offset2cylinder(disk_car,offset), offset2head(disk_car,offset), offset2sector(disk_car,offset),
+	      strerror(errno));
+	  return -1;
+	}
 #else
-    if(lseek(data->handle,offset+data->offset,SEEK_SET)==-1)
-    {
-      ecrit_rapport("file_read(%d,%u,buffer,%lu(%u/%u/%u)) seek err %s\n", data->handle,
-	  (unsigned)(count/disk_car->sector_size), (long unsigned int)(offset/disk_car->sector_size),
-	  offset2cylinder(disk_car,offset), offset2head(disk_car,offset), offset2sector(disk_car,offset),
-	  strerror(errno));
-      return -1;
-    }
+	if(lseek(data->handle,offset+data->offset,SEEK_SET)==-1)
+	{
+	  ecrit_rapport("file_read(%d,%u,buffer,%lu(%u/%u/%u)) seek err %s\n", data->handle,
+	      (unsigned)(count/disk_car->sector_size), (long unsigned int)(offset/disk_car->sector_size),
+	      offset2cylinder(disk_car,offset), offset2head(disk_car,offset), offset2sector(disk_car,offset),
+	      strerror(errno));
+	  return -1;
+	}
 #endif
 #if defined(__CYGWIN__)
-    {
-/* November 28, 2004, CGR: cygwin read function is about 10 times slower
-   because it reads 60k each time, so lets call ReadFile directly */
-      DWORD dwByteRead;
-      HANDLE handle=(HANDLE)get_osfhandle(data->handle);
-      ret=ReadFile(handle, nom_buffer,count,&dwByteRead,NULL);
-      if(ret)
-	ret=dwByteRead;
-    }
+	{
+	  /* November 28, 2004, CGR: cygwin read function is about 10 times slower
+	     because it reads 60k each time, so lets call ReadFile directly */
+	  DWORD dwByteRead;
+	  HANDLE handle=(HANDLE)get_osfhandle(data->handle);
+	  ret=ReadFile(handle, nom_buffer,count,&dwByteRead,NULL);
+	  if(ret==0)
+	    ret=-1;
+	  else
+	    ret=dwByteRead;
+	}
 #else
-    ret=read(data->handle, nom_buffer, count);
-#endif
+	ret=read(data->handle, nom_buffer, count);
 #endif
+      }
     /* Test only */
     /*
     if(!(offset+count<=120*512 || offset>=(120+1)*512))
@@ -1329,29 +1357,31 @@ static int file_write(t_param_disk *disk_car,const unsigned int count, const voi
   }
   else
   {
-    long int ret;
+    long int ret=-1;
     struct info_file_struct *data=disk_car->data;
 /*    ecrit_rapport("file_write offset=%lu data->offset=%lu\n",(long unsigned)offset,(long unsigned)data->offset); */
 #ifdef HAVE_PWRITE
       ret=pwrite(data->handle,nom_buffer,count,offset+data->offset);
-#else
+      if(ret<0 && errno == ENOSYS)
+#endif
+      {
 #ifdef __MINGW32__
-    if(_lseeki64(data->handle,offset+data->offset,SEEK_SET)==-1)
-    {
-      ecrit_rapport("file_write(%d,%u,buffer,%lu(%u/%u/%u)) seek err %s\n", data->handle,(unsigned)(count/disk_car->sector_size),(long unsigned)(offset/disk_car->sector_size),
-	  offset2cylinder(disk_car,offset),offset2head(disk_car,offset),offset2sector(disk_car,offset),strerror(errno));
-      return -1;
-    }
+	if(_lseeki64(data->handle,offset+data->offset,SEEK_SET)==-1)
+	{
+	  ecrit_rapport("file_write(%d,%u,buffer,%lu(%u/%u/%u)) seek err %s\n", data->handle,(unsigned)(count/disk_car->sector_size),(long unsigned)(offset/disk_car->sector_size),
+	      offset2cylinder(disk_car,offset),offset2head(disk_car,offset),offset2sector(disk_car,offset),strerror(errno));
+	  return -1;
+	}
 #else
-    if(lseek(data->handle,offset+data->offset,SEEK_SET)==-1)
-    {
-      ecrit_rapport("file_write(%d,%u,buffer,%lu(%u/%u/%u)) seek err %s\n", data->handle,(unsigned)(count/disk_car->sector_size),(long unsigned)(offset/disk_car->sector_size),
-	  offset2cylinder(disk_car,offset),offset2head(disk_car,offset),offset2sector(disk_car,offset),strerror(errno));
-      return -1;
-    }
-#endif
-    ret=write(data->handle, nom_buffer, count);
+	if(lseek(data->handle,offset+data->offset,SEEK_SET)==-1)
+	{
+	  ecrit_rapport("file_write(%d,%u,buffer,%lu(%u/%u/%u)) seek err %s\n", data->handle,(unsigned)(count/disk_car->sector_size),(long unsigned)(offset/disk_car->sector_size),
+	      offset2cylinder(disk_car,offset),offset2head(disk_car,offset),offset2sector(disk_car,offset),strerror(errno));
+	  return -1;
+	}
 #endif
+	ret=write(data->handle, nom_buffer, count);
+      }
     disk_car->write_used=1;
     if(ret!=count)
     {
@@ -1537,6 +1567,7 @@ t_param_disk *file_test_availability(const char *device, const int debug, const
     {
       void *real_buffer;
       unsigned char *buffer;
+      const uint8_t evf_file_signature[8] = { 'E', 'V', 'F', 0x09, 0x0D, 0x0A, 0xFF, 0x00 };
 #ifdef HAVE_POSIX_MEMALIGN
       if(posix_memalign(&real_buffer,DEFAULT_SECTOR_SIZE,DEFAULT_SECTOR_SIZE)!=0)
       {
@@ -1562,6 +1593,16 @@ t_param_disk *file_test_availability(const char *device, const int debug, const
 	offset=*(unsigned long*)(buffer+19);
 	disk_car->autodetect=0;
       }
+      else if(memcmp(buffer, evf_file_signature, 8)==0)
+      {
+	free(real_buffer);
+	close(hd_h);
+#if defined(HAVE_LIBEWF_H) && defined(HAVE_LIBEWF)
+	return fewf_init(device,debug,arch,testdisk_mode);
+#else
+	return NULL;
+#endif
+      }
       else
       {
 	if(stat_rec.st_size>offset)
@@ -1623,6 +1664,12 @@ t_param_disk *file_test_availability(const char *device, const int debug, const
     }
     close(hd_h);
   }
+  else
+  {
+#if defined(HAVE_LIBEWF_H) && defined(HAVE_LIBEWF) && defined(HAVE_GLOB_H)
+    return fewf_init(device,debug,arch,testdisk_mode);
+#endif
+  }
 #ifdef DJGPP
   {
    int   dos_nr=0;
@@ -1630,19 +1677,19 @@ t_param_disk *file_test_availability(const char *device, const int debug, const
     * XX is a value between 128 and 135 (0x80 to 0x88)      */
    if(strcmp(device, "/dev/sda128") == 0)
      dos_nr = 0x80;
-   if(strcmp(device, "/dev/sda129") == 0)
+   else if(strcmp(device, "/dev/sda129") == 0)
      dos_nr = 0x81;
-   if(strcmp(device, "/dev/sda130") == 0)
+   else if(strcmp(device, "/dev/sda130") == 0)
      dos_nr = 0x82;
-   if(strcmp(device, "/dev/sda131") == 0)
+   else if(strcmp(device, "/dev/sda131") == 0)
      dos_nr = 0x83;
-   if(strcmp(device, "/dev/sda132") == 0)
+   else if(strcmp(device, "/dev/sda132") == 0)
      dos_nr = 0x84;
-   if(strcmp(device, "/dev/sda133") == 0)
+   else if(strcmp(device, "/dev/sda133") == 0)
      dos_nr = 0x85;
-   if(strcmp(device, "/dev/sda134") == 0)
+   else if(strcmp(device, "/dev/sda134") == 0)
      dos_nr = 0x86;
-   if(strcmp(device, "/dev/sda135") == 0)
+   else if(strcmp(device, "/dev/sda135") == 0)
      dos_nr = 0x87;
    if(dos_nr>0)
      disk_car = hd_identify(debug, dos_nr, arch, testdisk_mode);
@@ -1753,7 +1800,7 @@ uint64_t filewin32_getfilesize(HANDLE handle, const char *device)
 	MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
 	(LPTSTR) &lpMsgBuf,
 	0, NULL );
-    ecrit_rapport("file_test_availability_win32(%s) GetFileSize err %s\n", device, (char*)lpMsgBuf);
+    ecrit_rapport("filewin32_getfilesize(%s) GetFileSize err %s\n", device, (char*)lpMsgBuf);
     LocalFree(lpMsgBuf);
     return 0;
   }
@@ -1778,7 +1825,7 @@ uint64_t filewin32_setfilepointer(HANDLE handle, const char *device)
 	MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
 	(LPTSTR) &lpMsgBuf,
 	0, NULL );
-    ecrit_rapport("file_test_availability_win32(%s) SetFilePointer err %s\n", device, (char*)lpMsgBuf);
+    ecrit_rapport("filewin32_setfilepointer(%s) SetFilePointer err %s\n", device, (char*)lpMsgBuf);
     LocalFree(lpMsgBuf);
     return 0;
   }
@@ -1800,6 +1847,24 @@ t_param_disk *file_test_availability_win32(const char *device, const int debug,
 	NULL, OPEN_EXISTING, 0, NULL);
     if (handle == INVALID_HANDLE_VALUE)
     {
+      if(debug>1)
+      {
+#ifdef __MINGW32__
+	ecrit_rapport("file_test_availability_win32 RW failed %s\n", device);
+#else
+	LPVOID buf;
+	FormatMessage( FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM
+	    , NULL
+	    , GetLastError()
+	    , MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT)
+	    , (LPTSTR)&buf
+	    , 0
+	    , NULL 
+	    );
+	ecrit_rapport("file_test_availability_win32 RW failed: %s:%s\n", device,(const char*)buf);
+	LocalFree(buf);
+#endif
+      }
       try_readonly=0;
     }
   }
@@ -1812,7 +1877,21 @@ t_param_disk *file_test_availability_win32(const char *device, const int debug,
     {
       if(debug>1)
       {
-	ecrit_rapport("file_test_availability_win32 %s error\n", device);
+#ifdef __MINGW32__
+	ecrit_rapport("file_test_availability_win32 RO %s error\n", device);
+#else
+	LPVOID buf;
+	FormatMessage( FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM
+	    , NULL
+	    , GetLastError()
+	    , MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT)
+	    , (LPTSTR)&buf
+	    , 0
+	    , NULL 
+	    );
+	ecrit_rapport("file_test_availability_win32 RO failed: %s:%s\n", device,(const char*)buf);
+	LocalFree(buf);
+#endif
       }
     }
   }
@@ -1822,8 +1901,11 @@ t_param_disk *file_test_availability_win32(const char *device, const int debug,
     disk_car=disk_get_geometry_win32(handle,device,debug);
     if (disk_car!=NULL)
     {
-      /* if(disk_car->sector_size!=4096) */
+      if(device[0]=='\\' && device[1]=='\\' && device[2]=='.' && device[3]=='\\' && device[5]==':'
+	  && disk_car->sector_size==512)
       {
+	if(debug>1)
+	  ecrit_rapport("%s is available but reject it to avoid duplicate disk.\n", device);
 	free(disk_car);
 	CloseHandle(handle);
 	return NULL;
@@ -1831,7 +1913,6 @@ t_param_disk *file_test_availability_win32(const char *device, const int debug,
     }
     else
     {
-
       uint64_t i64FreeBytesToCaller, i64TotalBytes, i64FreeBytes;
       DWORD dwSectPerClust, 
 	    dwBytesPerSect, 
@@ -1912,9 +1993,14 @@ static const char *file_win32_description(t_param_disk *disk_car)
 {
   struct info_file_win32_struct *data=disk_car->data;
   char buffer_disk_size[100];
-  snprintf(disk_car->description_txt, sizeof(disk_car->description_txt),"Drive %c: - %s - CHS %u %u %u",
-      data->file_name[4], size_to_unit(disk_car->disk_size,buffer_disk_size),
-      disk_car->CHS.cylinder+1, disk_car->CHS.head+1, disk_car->CHS.sector);
+  if(data->file_name[0]=='\\' && data->file_name[1]=='\\' && data->file_name[2]=='.' && data->file_name[3]=='\\' && data->file_name[5]==':')
+    snprintf(disk_car->description_txt, sizeof(disk_car->description_txt),"Drive %c: - %s - CHS %u %u %u",
+	data->file_name[4], size_to_unit(disk_car->disk_size,buffer_disk_size),
+	disk_car->CHS.cylinder+1, disk_car->CHS.head+1, disk_car->CHS.sector);
+  else
+    snprintf(disk_car->description_txt, sizeof(disk_car->description_txt),"Disk %s - %s - CHS %u %u %u",
+	data->file_name, size_to_unit(disk_car->disk_size,buffer_disk_size),
+	disk_car->CHS.cylinder+1, disk_car->CHS.head+1, disk_car->CHS.sector);
   return disk_car->description_txt;
 }
 
@@ -1922,8 +2008,12 @@ static const char *file_win32_description_short(t_param_disk *disk_car)
 {
   struct info_file_win32_struct *data=disk_car->data;
   char buffer_disk_size[100];
-  snprintf(disk_car->description_short_txt, sizeof(disk_car->description_txt),"Drive %c: - %s",
-      data->file_name[4], size_to_unit(disk_car->disk_size,buffer_disk_size));
+  if(data->file_name[0]=='\\' && data->file_name[1]=='\\' && data->file_name[2]=='.' && data->file_name[3]=='\\' && data->file_name[5]==':')
+    snprintf(disk_car->description_short_txt, sizeof(disk_car->description_txt),"Drive %c: - %s",
+	data->file_name[4], size_to_unit(disk_car->disk_size,buffer_disk_size));
+  else
+    snprintf(disk_car->description_short_txt, sizeof(disk_car->description_txt),"Disk %s - %s",
+	data->file_name, size_to_unit(disk_car->disk_size,buffer_disk_size));
   return disk_car->description_short_txt;
 }
 
