@@ -84,23 +84,25 @@ static int cache_read_aux(t_param_disk *disk_car,const unsigned int count, void
 	  data->cache[i].cache_offset <= offset &&
 	  offset < data->cache[i].cache_offset +data->cache[i].cache_size)
       {
-	unsigned data_avaible=data->cache[i].cache_offset +data->cache[i].cache_size-offset;
-	data->nbr_fnct_sect+=count;
+	unsigned data_available=data->cache[i].cache_offset +data->cache[i].cache_size-offset;
 #ifdef DEBUG_CACHE
 	ecrit_rapport("use cache %u count=%u, offset=%llu\n",i,
 	    data->cache[i].cache_size, data->cache[i].cache_offset);
 #endif
 	res=data->cache[i].cache_status;
-	if(count<=data_avaible)
+	if(count<=data_available)
 	{
-	  memcpy(nom_buffer, data->cache[i].buffer+offset-data->cache[i].cache_offset,count);
+	  data->nbr_fnct_sect+=count;
+	  memcpy(nom_buffer, data->cache[i].buffer+offset-data->cache[i].cache_offset, count);
 	  return res;
 	}
+	else
 	{
 	  int newres;
-	  data->nbr_fnct_sect-=count-data_avaible;
-	  memcpy(nom_buffer, data->cache[i].buffer+offset-data->cache[i].cache_offset, data_avaible);
-	  newres=cache_read_aux(disk_car,count-data_avaible,(unsigned char*)nom_buffer+data_avaible,offset+data_avaible,can_read_more);
+	  data->nbr_fnct_sect+=data_available;
+	  memcpy(nom_buffer, data->cache[i].buffer+offset-data->cache[i].cache_offset, data_available);
+	  newres=cache_read_aux(disk_car, count-data_available,
+	      (unsigned char*)nom_buffer+data_available, offset+data_available, can_read_more);
 	  if(res>=0)
 	    res=newres;
 	  return res;
@@ -132,7 +134,7 @@ static int cache_read_aux(t_param_disk *disk_car,const unsigned int count, void
 #endif
     if(data->cache[data->cache_buffer_nbr].buffer==NULL)
       data->cache[data->cache_buffer_nbr].buffer=MALLOC(CACHE_SIZE_MAX);
-    res=data->disk_car->read(data->disk_car,count_new,data->cache[data->cache_buffer_nbr].buffer,offset);
+    res=data->disk_car->read(data->disk_car, count_new, data->cache[data->cache_buffer_nbr].buffer, offset);
     data->cache[data->cache_buffer_nbr].cache_size=count_new;
     data->cache[data->cache_buffer_nbr].cache_offset=offset;
     data->cache[data->cache_buffer_nbr].cache_status=res;
@@ -142,7 +144,7 @@ static int cache_read_aux(t_param_disk *disk_car,const unsigned int count, void
       if(count<=disk_car->sector_size || disk_car->sector_size<=0)
       {
 	memset(data->cache[data->cache_buffer_nbr].buffer, 0, data->cache[data->cache_buffer_nbr].cache_size);
-	memcpy(nom_buffer,data->cache[data->cache_buffer_nbr].buffer,count);
+	memcpy(nom_buffer, data->cache[data->cache_buffer_nbr].buffer, count);
 	data->cache_buffer_nbr=(data->cache_buffer_nbr+1)%CACHE_BUFFER_NBR;
 	return res;
       }
@@ -159,7 +161,7 @@ static int cache_read_aux(t_param_disk *disk_car,const unsigned int count, void
       }
       return res;
     }
-    memcpy(nom_buffer,data->cache[data->cache_buffer_nbr].buffer,count);
+    memcpy(nom_buffer, data->cache[data->cache_buffer_nbr].buffer, count);
 #ifdef DEBUG_CACHE
     ecrit_rapport("cache_read offset=%llu size=%lu, update cache %u, res=%d\n",
 	(long long unsigned)data->cache[data->cache_buffer_nbr].cache_offset,
