@@ -40,15 +40,13 @@
 #define COLUMNS 		80
 
 
-#define COMMAND_LINE_X		0
-#define COMMAND_LINE_Y  	18
 #define DUMP_X			0
 #define DUMP_Y			5 + 2
 #define DUMP_MAX_LINES		14
 #define INTER_DUMP_X		DUMP_X
 #define INTER_DUMP_Y		DUMP_Y+DUMP_MAX_LINES+1
 #define INTER_ANALYSE_X		0
-#define INTER_ANALYSE_Y 	7
+#define INTER_ANALYSE_Y 	8
 #define INTER_MAX_LINES 	13
 #define INTER_ANALYSE_MENU_X 	0
 #define INTER_ANALYSE_MENU_Y 	23
@@ -58,6 +56,8 @@
 #define INTER_PARTITION_Y	8
 #define INTER_MAIN_X		0
 #define INTER_MAIN_Y		18
+#define INTER_GEOM_X		0
+#define INTER_GEOM_Y  		18
 /* Constants for menuType parameter of menuSelect function */
 #define MENU_HORIZ 		1
 #define MENU_VERT 		2
@@ -111,14 +111,14 @@ void dump2_log(const void *dump_1, const void *dump_2,const unsigned int lng);
 void dump2(WINDOW *window,const void *dump_1, const void *dump_2,const unsigned int lng);
 int wgetch_nodelay(WINDOW *window);
 int wmenuUpdate(WINDOW *window, int y, int x, const struct MenuItem *menuItems, const unsigned int itemLength, const char *available, const int menuType, unsigned int current);
-int wmenuSimple(WINDOW *window, const struct MenuItem *menuItems, int menuDefault);
+int wmenuSimple(WINDOW *window, const struct MenuItem *menuItems, unsigned int menuDefault);
 void aff_copy(WINDOW *window);
 int ask_YN(WINDOW *window);
 void not_implemented(const char *msg);
 int start_ncurses(const char *prog_name, const char *real_prog_name);
 int end_ncurses(void);
 int screen_buffer_display(WINDOW *window, const char *options_org, const struct MenuItem *menuItems);
-int screen_buffer_display_ext(WINDOW *window, const char *options_org, const struct MenuItem *menuItems, int *menu);
+int screen_buffer_display_ext(WINDOW *window, const char *options_org, const struct MenuItem *menuItems, unsigned int *menu);
 void screen_buffer_to_log(void);
 int check_enter_or_s(WINDOW *window);
 int interface_partition_type(t_param_disk *disk_car, const int allow_partial_last_cylinder, const int debug, char**current_cmd);
@@ -128,4 +128,5 @@ int ask_log_creation(void);
 FILE* log_open(const char*default_filename, const char *mode, const char *prog_name, int argc, char**argv);
 char *ask_location(const char*msg, const char *src_dir);
 int aff_txt(int line, WINDOW *window, const char *_format, ...) __attribute__ ((format (printf, 3, 4)));
+int vaff_txt(int line, WINDOW *window, const char *_format, va_list ap);
 
