@@ -67,6 +67,8 @@ static t_list_part *interface_load(t_param_disk *disk_car,t_list_part *list_part
 static t_list_part *backup_merge(t_list_part *list_part,t_list_part *backup_part, const int debug);
 static int write_MBR_code(t_param_disk *disk_car, char **current_cmd);
 static int write_clean_table(t_param_disk *disk_car, char **current_cmd);
+static int interface_check_disk_capacity(t_param_disk *disk_car);
+static t_list_part *interface_analyse(t_param_disk *disk_car, const int debug, const int saveheader, char**current_cmd);
 
 void interface_list(t_param_disk *disk_car, const int debug,const int test_recovery, const int saveheader, const int backup)
 {
@@ -155,7 +157,7 @@ static int menu_disk(t_param_disk *disk_car, int debug,int dump_ind, const int s
   int ask_part_order=0;
   int command;
   int done=0;
-  int menu=0;
+  unsigned int menu=0;
   int real_key;
   unsigned int expert=0;
   char options[16];
@@ -232,8 +234,12 @@ static int menu_disk(t_param_disk *disk_car, int debug,int dump_ind, const int s
     {
       case 'a':
       case 'A':
-	interface_analyse(disk_car, debug, saveheader, current_cmd);
-	interface_recovery(disk_car, debug, dump_ind, align, ask_part_order, expert, current_cmd);
+	{
+	  t_list_part *list_part;
+	  list_part=interface_analyse(disk_car, debug, saveheader, current_cmd);
+	  interface_recovery(disk_car, list_part, debug, dump_ind, align, ask_part_order, expert, current_cmd);
+	  delete_list_part(list_part);
+	}
 	break;
       case 'd':
       case 'D':
@@ -278,7 +284,7 @@ int do_curses_testdisk(int debug,int dump_ind, const t_list_disk *list_disk, con
   int command='Q';
   int allow_partial_last_cylinder=0;
   int done=0;
-  int menu=0;
+  unsigned int menu=0;
   int offset=0;
   int pos_num=0;
   const t_list_disk *element_disk;
@@ -318,6 +324,7 @@ int do_curses_testdisk(int debug,int dump_ind, const t_list_disk *list_disk, con
     wdoprintf(stdscr,"comes with ABSOLUTELY NO WARRANTY.");
     wmove(stdscr,7,0);
     wdoprintf(stdscr,"Select a media (use Arrow keys, then press Enter):");
+    /* TODO: Detect the LBA28 limitation */
     for(i=0,element_disk=list_disk;(element_disk!=NULL) && (i<offset);element_disk=element_disk->next,i++);
     for(;element_disk!=NULL && (i-offset)<10;i++,element_disk=element_disk->next)
     {
@@ -405,11 +412,11 @@ int do_curses_testdisk(int debug,int dump_ind, const t_list_disk *list_disk, con
 	break;
       case 'o':
       case 'O':
-	if(interface_partition_type(current_disk->disk, allow_partial_last_cylinder, debug, current_cmd)==0)
+        if(interface_check_disk_capacity(current_disk->disk)==0 &&
+	    interface_partition_type(current_disk->disk, allow_partial_last_cylinder, debug, current_cmd)==0)
 	{
 	  if(menu_disk(current_disk->disk, debug, dump_ind, saveheader, current_cmd))
 	    done=1;
-	  menu=3; /* select quit */
 	}
 	break;
       case 'q':
@@ -421,7 +428,45 @@ int do_curses_testdisk(int debug,int dump_ind, const t_list_disk *list_disk, con
   return 0;
 }
 
-void interface_analyse(t_param_disk *disk_car, const int debug, const int saveheader, char**current_cmd)
+static int interface_check_disk_capacity(t_param_disk *disk_car)
+{
+  /* Test for LBA28 limitation */
+  if(disk_car->CHS.sector>0 && (disk_car->CHS.cylinder+1) == (((1<<28)-1) / (disk_car->CHS.head+1) / disk_car->CHS.sector))
+  {
+    static const struct MenuItem menuMain[]=
+    {
+      { 'C', "Continue","The HD is really 137 GB only."},
+      { 'Q',"Quit","The HD is bigger, it's safer to enable LBA48 support first."},
+      { 0,NULL,NULL}
+    };
+    unsigned int menu=1;
+    int car;
+    ecrit_rapport("LBA28 limitation\n");
+    aff_copy(stdscr);
+    if(disk_car->arch->msg_part_type!=NULL)
+      mvwaddstr(stdscr,22,0,disk_car->arch->msg_part_type);
+    wmove(stdscr,4,0);
+    wdoprintf(stdscr,"%s\n",disk_car->description(disk_car));
+    wmove(stdscr,6,0);
+    wdoprintf(stdscr,"The Harddisk size seems to be 137GB.");
+    wmove(stdscr,7,0);
+    wdoprintf(stdscr,"Support for 48-bit Logical Block Addressing (LBA) is needed to access");
+    wmove(stdscr,8,0);
+    wdoprintf(stdscr,"hard disks larger than 137 GB.");
+    wmove(stdscr,9,0);
+#if defined(__CYGWIN__) || defined(__MINGW32__)
+    wdoprintf(stdscr,"Update Windows to support LBA48 (minimum: W2K SP4 or XP SP1)");
+#endif
+    car= wmenuSelect_ext(stdscr,INTER_MAIN_Y, INTER_MAIN_X, menuMain, 10,
+	    "CQ", MENU_VERT | MENU_VERT_WARN | MENU_BUTTON, &menu,NULL);
+    if(car=='c' || car=='C')
+      return 0;
+    return 1;
+  }
+  return 0;
+}
+
+static t_list_part *interface_analyse(t_param_disk *disk_car, const int debug, const int saveheader, char**current_cmd)
 {
   t_list_part *list_part;
   int command;
@@ -439,7 +484,7 @@ void interface_analyse(t_param_disk *disk_car, const int debug, const int savehe
   /* ncurses interface */
   aff_copy(stdscr);
   if(disk_car->arch->msg_part_type!=NULL)
-    mvwaddstr(stdscr,21,0,disk_car->arch->msg_part_type);
+    mvwaddstr(stdscr,22,0,disk_car->arch->msg_part_type);
   wmove(stdscr,4,0);
   wdoprintf(stdscr,"%s\n",disk_car->description(disk_car));
   mvwaddstr(stdscr,5,0,"Checking current partition structure");
@@ -474,10 +519,10 @@ void interface_analyse(t_param_disk *disk_car, const int debug, const int savehe
       display_message("Can't create backup.log.\n");
     }
   }
-  delete_list_part(list_part);
+  return list_part;
 }
 
-int interface_write(t_param_disk *disk_car,t_list_part *list_part,const int can_search_deeper, const int can_ask_minmax_ext, char **current_cmd, int *menu)
+int interface_write(t_param_disk *disk_car,t_list_part *list_part,const int can_search_deeper, const int can_ask_minmax_ext, char **current_cmd, unsigned int *menu)
 {
   t_list_part *parts;
   struct MenuItem menuWrite[]=
@@ -553,7 +598,7 @@ int interface_write(t_param_disk *disk_car,t_list_part *list_part,const int can_
       if(disk_car->arch->write_part!=NULL)
 	strcat(options,"W");
       else
-	aff_buffer(BUFFER_ADD," \nWrite isn't avaible because the partition table type \"%s\" has been selected.",
+	aff_buffer(BUFFER_ADD," \nWrite isn't available because the partition table type \"%s\" has been selected.",
 	    disk_car->arch->part_name);
       if(can_ask_minmax_ext)
 	strcat(options,"E");
@@ -581,7 +626,7 @@ static void interface_options(int *dump_ind, int *align, int *allow_partial_last
   else
   {
     int done = FALSE;
-    int menu = 4;
+    unsigned int menu = 4;
     /* ncurses interface */
     while (done==FALSE)
     {
@@ -982,7 +1027,7 @@ static t_list_part *interface_load(t_param_disk *disk_car,t_list_part *list_part
     int offset=0;
     int backup_current_num=0;
     int rewrite=1;
-    int menu=3;   /* default : quit */
+    unsigned int menu=3;   /* default : quit */
     struct list_head *backup_current=backup_list->list.next;
     struct MenuItem menuLoadBackup[]=
     {
