@@ -39,6 +39,9 @@
 #include "lang.h"
 #include "io_redir.h"
 
+#define INTER_NTFS_X 0
+#define INTER_NTFS_Y 23
+
 static int create_ntfs_boot_sector(t_param_disk *disk_car, t_partition *partition, const int interface, const unsigned int cluster_size, const uint64_t mft_lcn, const uint64_t mftmirr_lcn, const uint32_t mft_record_size, const uint32_t index_block_size, char**current_cmd);
 static int dump_2ntfs_info(const struct ntfs_boot_sector *nh1, const struct ntfs_boot_sector *nh2);
 static int dump_ntfs_info(const struct ntfs_boot_sector *ntfs_header);
@@ -385,7 +388,7 @@ int rebuild_NTFS_BS(t_param_disk *disk_car, t_partition *partition, const int de
       wrefresh(stdscr);
       if(check_enter_or_s(stdscr))
       {
-	ecrit_rapport("Search mft stopped: %10lu/%lu)\n", (long unsigned)sector,
+	ecrit_rapport("Search mft stopped: %10lu/%lu\n", (long unsigned)sector,
 	    (long unsigned)(partition->part_size/disk_car->sector_size));
 	ind_stop=TRUE;
       }
@@ -412,9 +415,13 @@ int rebuild_NTFS_BS(t_param_disk *disk_car, t_partition *partition, const int de
   }
   if(interface>0 && expert>0)
   {
+    wmove(stdscr, INTER_NTFS_Y, INTER_NTFS_X);
     sectors_per_cluster=ask_number(sectors_per_cluster,0,512,"Sectors per cluster ");
+    wmove(stdscr, INTER_NTFS_Y, INTER_NTFS_X);
     mft_lcn=ask_number(mft_lcn,0,0,"MFT LCN ");
+    wmove(stdscr, INTER_NTFS_Y, INTER_NTFS_X);
     mftmirr_lcn=ask_number(mftmirr_lcn,0,0,"MFTMIRR LCN ");
+    wmove(stdscr, INTER_NTFS_Y, INTER_NTFS_X);
     mft_record_size=ask_number(mft_record_size,0,4096," mft record size ");
   }
   /* TODO read_mft_info(partition,sector,*sectors_per_cluster,*mft_lcn,*mftmirr_lcn,*mft_record_size); */
