@@ -386,7 +386,7 @@ static int ntfs_copy(t_param_disk *disk_car, const t_partition *partition, t_dir
   inode = ntfs_inode_open (ls->vol, first_inode);
   if (!inode) {
     ecrit_rapport("ntfs_copy: ntfs_inode_open failed\n");
-    return 1;
+    return -1;
   }
   {
     const int bufsize = 4096;
@@ -399,13 +399,13 @@ static int ntfs_copy(t_param_disk *disk_car, const t_partition *partition, t_dir
     u32 block_size;
     buffer = MALLOC(bufsize);
     if (!buffer)
-      return 2;
+      return -2;
     attr = ntfs_attr_open(inode, AT_DATA, NULL, 0);
     if (!attr)
     {
       ecrit_rapport("Cannot find attribute type 0x%lx.\n", (long) AT_DATA);
       free(buffer);
-      return 3;
+      return -3;
     }
     if ((inode->mft_no < 2) && (attr->type == AT_DATA))
       block_size = ls->vol->mft_record_size;
@@ -421,7 +421,7 @@ static int ntfs_copy(t_param_disk *disk_car, const t_partition *partition, t_dir
     {
       ecrit_rapport("Can't create file %s: %s\n",new_file, strerror(errno));
       free(new_file);
-      return 4;
+      return -4;
     }
     free(new_file);
     offset = 0;
@@ -483,6 +483,11 @@ int dir_partition_ntfs_init(t_param_disk *disk_car, const t_partition *partition
   ntfs_volume *vol=NULL;
   if(partition->boot_sector!=0)
     io_redir_add_redir(disk_car,partition->part_offset,DEFAULT_SECTOR_SIZE,partition->part_offset+(uint64_t)partition->boot_sector*disk_car->sector_size,NULL);
+#ifdef NTFS_LOG_LEVEL_VERBOSE
+  ntfs_log_set_levels(NTFS_LOG_LEVEL_VERBOSE);
+  ntfs_log_set_handler(ntfs_log_handler_stderr);
+#endif
+
   dev = ntfs_device_alloc("/", 0, &ntfs_device_testdisk_io_ops, NULL);
   if (dev)
   {
@@ -493,6 +498,15 @@ int dir_partition_ntfs_init(t_param_disk *disk_car, const t_partition *partition
     dev->d_private=my_data;
     /* Call ntfs_device_mount() to do the actual mount. */
     vol = ntfs_device_mount(dev, MS_RDONLY);
+#ifdef HAVE_NTFS_VOLUME_STARTUP
+    if(!vol) {
+      vol = ntfs_volume_startup(dev, MS_RDONLY);
+      if(vol)
+      {
+	ecrit_rapport("NTFS filesystem need to be repaired.\n");
+      }
+    }
+#endif
   }
   if (!vol) {
     if(partition->boot_sector!=0)
@@ -502,7 +516,7 @@ int dir_partition_ntfs_init(t_param_disk *disk_car, const t_partition *partition
     return -1;
   }
   if (vol->flags & VOLUME_IS_DIRTY) {
-    ecrit_rapport("Volume is dirty.\n");
+    ecrit_rapport("NTFS Volume is dirty.\n");
   }
   {
     struct list_dir_struct *ls=(struct list_dir_struct *)MALLOC(sizeof(*ls));
@@ -531,7 +545,7 @@ const char*td_ntfs_version(void)
 #ifdef HAVE_NTFS_LIBNTFS_VERSION
   return ntfs_libntfs_version();
 #else
-  return "avaible";
+  return "available";
 #endif
 #else
   return "none";
