@@ -15,8 +15,8 @@
     GNU General Public License for more details.
   
     You should have received a copy of the GNU General Public License along
-    with this program; if not, write the Free Software Foundation, Inc., 59
-    Temple Place - Suite 330, Boston MA 02111-1307, USA.
+    with this program; if not, write the Free Software Foundation, Inc., 51
+    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  */
 
@@ -115,8 +115,8 @@ static int check_part_i386(t_param_disk *disk_car, const int debug,t_partition *
 static void partition2_i386_entry(const t_param_disk *disk_car,const uint64_t pos,const t_partition *partition, struct partition_dos *p);
 static int i386_entry2partition(t_param_disk *disk_car, const uint64_t offset, t_partition *partition, const struct partition_dos *p, const status_type_t status,const unsigned int order,const int debug, const int saveheader);
 static const char* errmsg_i386_entry2partition(const errcode_type_t errcode);
-static const unsigned char *get_partition_name_i386(const t_partition *partition);
-static const unsigned char *get_partition_name_i386_aux(const unsigned int part_type_i386);
+static const char *get_partition_name_i386(const t_partition *partition);
+static const char *get_partition_name_i386_aux(const unsigned int part_type_i386);
 static unsigned int get_part_type_i386(const t_partition *partition);
 
 static const struct systypes i386_sys_types[] = {
@@ -345,13 +345,13 @@ static t_list_part *read_part_i386(t_param_disk *disk_car, const int debug, cons
   if(disk_car->read(disk_car,disk_car->sector_size, buffer, (uint64_t)0))
   {
     wdoprintf(stdscr,msg_PART_RD_ERR);
-    FREE(buffer);
+    free(buffer);
     return NULL;
   }
   if(get_geometry_from_i386mbr(buffer,debug,&geometry)!=0)
   {
     aff_buffer(BUFFER_ADD,msg_TBL_NMARK);
-    FREE(buffer);
+    free(buffer);
     return NULL;
   }
   for(i=0;i<4;i++)
@@ -391,7 +391,7 @@ static t_list_part *read_part_i386(t_param_disk *disk_car, const int debug, cons
       new_list_part=get_ext_data_i386(disk_car,new_list_part,debug,saveheader);
   }
   get_geometry_from_list_part(disk_car, new_list_part, debug);
-  FREE(buffer);
+  free(buffer);
   return new_list_part;
 }
 
@@ -503,15 +503,15 @@ static t_list_part *get_ext_data_i386(t_param_disk *disk_car, t_list_part *list_
 	}
       }
       if(nb_hidden>0)
-	aff_buffer(BUFFER_ADD,"Partition musn't be hidden\n");
+	aff_buffer(BUFFER_ADD,"Partition must not be hidden\n");
       if(nb_mb>0)
 	aff_buffer(BUFFER_ADD,"Multiboot must be a primary partition, not a logical\n");
       if(nb_ext>1)
-	aff_buffer(BUFFER_ADD,"A logical partition musn't have more than one link to another logical partition\n");
+	aff_buffer(BUFFER_ADD,"A logical partition must not have more than one link to another logical partition\n");
       if(nb_part>1)
 	aff_buffer(BUFFER_ADD,"A logical partition must contain only one partition\n");
       if(nb_boot>0)
-	aff_buffer(BUFFER_ADD,"Logical partition musn't be bootable\n");
+	aff_buffer(BUFFER_ADD,"Logical partition must not be bootable\n");
       partition_next_ext=NULL;
       for(i=0;i<4;i++)
       {
@@ -550,7 +550,7 @@ static t_list_part *get_ext_data_i386(t_param_disk *disk_car, t_list_part *list_
 		  {
 		    if(((partition->part_offset>=new_partition->part_offset) && (partition->part_offset<=new_partition->part_offset+new_partition->part_size-1)) ||
 			((partition->part_offset+partition->part_size-1>=new_partition->part_offset) && (partition->part_offset+partition->part_size-1<=new_partition->part_offset+partition->part_size-1)))
-		    { /* New Partition start or end musn't been in partition */
+		    { /* New Partition start or end mustn't been in partition */
 		      res=1;
 		      aff_buffer(BUFFER_ADD, "Logical partition must be in its own extended partition\n");
 		      aff_part_buffer(AFF_PART_ORDER,disk_car,partition);
@@ -675,13 +675,13 @@ static int write_mbr_i386(t_param_disk *disk_car, const t_list_part *list_part,
   {
     if(disk_car->write(disk_car,DEFAULT_SECTOR_SIZE, buffer, (uint64_t)0))
     {
-      FREE(buffer_org);
-      FREE(buffer);
+      free(buffer_org);
+      free(buffer);
       return 1;
     }
   }
-  FREE(buffer_org);
-  FREE(buffer);
+  free(buffer_org);
+  free(buffer);
   return 0;
 }
 
@@ -832,7 +832,7 @@ static int write_all_log_i386(t_param_disk *disk_car, const t_list_part *list_pa
       current_pos=bloc_nextext->part_offset;
     }
   }
-  FREE(bloc_nextext);
+  free(bloc_nextext);
   return res;
 }
 
@@ -1159,7 +1159,7 @@ static int test_structure_i386(t_list_part *list_part)
   for(element=new_list_part;element!=NULL;element=new_element)
   {
     new_element=element->next;
-    FREE(element);
+    free(element);
   }
   return res;
 }
@@ -1204,32 +1204,38 @@ static t_list_part *add_partition_i386(t_param_disk *disk_car,t_list_part *list_
       wmove(stdscr,10, 0);
       wclrtoeol(stdscr);
       aff_part(stdscr,AFF_PART_SHORT,disk_car,new_partition);
-      wmove(stdscr,COMMAND_LINE_Y, COMMAND_LINE_X);
+      wmove(stdscr,INTER_GEOM_Y, INTER_GEOM_X);
       wclrtoeol(stdscr);
       wrefresh(stdscr);
       command=wmenuSimple(stdscr,menuGeometry, position);
       switch (command) {
 	case 'c':
+	  wmove(stdscr, INTER_GEOM_Y, INTER_GEOM_X);
 	  start.cylinder=ask_number(start.cylinder,0,disk_car->CHS.cylinder,"Enter the starting cylinder ");
 	  position=1;
 	  break;
 	case 'h':
+	  wmove(stdscr, INTER_GEOM_Y, INTER_GEOM_X);
 	  start.head=ask_number(start.head,0,disk_car->CHS.head,"Enter the starting head ");
 	  position=2;
 	  break;
 	case 's':
+	  wmove(stdscr, INTER_GEOM_Y, INTER_GEOM_X);
 	  start.sector=ask_number(start.sector,1,disk_car->CHS.sector,"Enter the starting sector ");
 	  position=3;
 	  break;
 	case 'C':
+	  wmove(stdscr, INTER_GEOM_Y, INTER_GEOM_X);
 	  end.cylinder=ask_number(end.cylinder,start.cylinder,disk_car->CHS.cylinder,"Enter the ending cylinder ");
 	  position=4;
 	  break;
 	case 'H':
+	  wmove(stdscr, INTER_GEOM_Y, INTER_GEOM_X);
 	  end.head=ask_number(end.head,0,disk_car->CHS.head,"Enter the ending head ");
 	  position=5;
 	  break;
 	case 'S':
+	  wmove(stdscr, INTER_GEOM_Y, INTER_GEOM_X);
 	  end.sector=ask_number(end.sector,1,disk_car->CHS.sector,"Enter the ending sector ");
 	  position=6;
 	  break;
@@ -1269,7 +1275,7 @@ static t_list_part *add_partition_i386(t_param_disk *disk_car,t_list_part *list_
     }
     return new_list_part;
   }
-  FREE(new_partition);
+  free(new_partition);
   return list_part;
 }
 
@@ -1419,7 +1425,7 @@ static void init_structure_i386(const t_param_disk *disk_car,t_list_part *list_p
     for(element=new_list_part;element!=NULL;element=new_element)
     {
       new_element=element->next;
-      FREE(element);
+      free(element);
     }
   }
 #ifdef DEBUG
@@ -1554,7 +1560,7 @@ static int check_part_i386(t_param_disk *disk_car,const int debug,t_partition *p
   return ret;
 }
 
-static const unsigned char *get_partition_name_i386_aux(const unsigned int part_type_i386)
+static const char *get_partition_name_i386_aux(const unsigned int part_type_i386)
 {
   int i;
   for (i=0; i386_sys_types[i].name!=NULL; i++)
@@ -1563,7 +1569,7 @@ static const unsigned char *get_partition_name_i386_aux(const unsigned int part_
   return NULL;
 }
 
-static const unsigned char *get_partition_name_i386(const t_partition *partition)
+static const char *get_partition_name_i386(const t_partition *partition)
 {
   return get_partition_name_i386_aux(partition->part_type_i386);
 }
