@@ -62,8 +62,8 @@ static int test_structure_mac(t_list_part *list_part);
 static int set_part_type_mac(t_partition *partition, unsigned int part_type_mac);
 static int is_part_known_mac(const t_partition *partition);
 static void init_structure_mac(const t_param_disk *disk_car,t_list_part *list_part, const int debug);
-static const unsigned char *get_partition_name_mac(const t_partition *partition);
-static const unsigned char *get_partition_name_mac_aux(const unsigned int part_type_mac);
+static const char *get_partition_name_mac(const t_partition *partition);
+static const char *get_partition_name_mac_aux(const unsigned int part_type_mac);
 static unsigned int get_part_type_mac(const t_partition *partition);
 
 static const struct systypes mac_sys_types[] = {
@@ -279,16 +279,18 @@ static t_list_part *add_partition_mac(t_param_disk *disk_car,t_list_part *list_p
       wmove(stdscr,10, 0);
       wclrtoeol(stdscr);
       aff_part(stdscr,AFF_PART_SHORT,disk_car,new_partition);
-      wmove(stdscr,COMMAND_LINE_Y, COMMAND_LINE_X);
+      wmove(stdscr,INTER_GEOM_Y, INTER_GEOM_X);
       wclrtoeol(stdscr);
       wrefresh(stdscr);
       command=wmenuSimple(stdscr,menuGeometry, position);
       switch (command) {
 	case 'c':
+	  wmove(stdscr, INTER_GEOM_Y, INTER_GEOM_X);
 	  start.cylinder=ask_number(start.cylinder,0,disk_car->CHS.cylinder,"Enter the starting cylinder ");
 	  position=1;
 	  break;
 	case 'C':
+	  wmove(stdscr, INTER_GEOM_Y, INTER_GEOM_X);
 	  end.cylinder=ask_number(end.cylinder,start.cylinder,disk_car->CHS.cylinder,"Enter the ending cylinder ");
 	  position=2;
 	  break;
@@ -485,7 +487,7 @@ static int check_part_mac(t_param_disk *disk_car,const int debug,t_partition *pa
   return ret;
 }
 
-static const unsigned char *get_partition_name_mac_aux(const unsigned int part_type_mac)
+static const char *get_partition_name_mac_aux(const unsigned int part_type_mac)
 {
   int i;
   for (i=0; mac_sys_types[i].name!=NULL; i++)
@@ -494,7 +496,7 @@ static const unsigned char *get_partition_name_mac_aux(const unsigned int part_t
   return NULL;
 }
 
-static const unsigned char *get_partition_name_mac(const t_partition *partition)
+static const char *get_partition_name_mac(const t_partition *partition)
 {
   return get_partition_name_mac_aux(partition->part_type_mac);
 }
