@@ -72,8 +72,8 @@ static int test_structure_none(t_list_part *list_part);
 static int set_part_type_none(t_partition *partition, unsigned int part_type);
 static int is_part_known_none(const t_partition *partition);
 static void init_structure_none(const t_param_disk *disk_car,t_list_part *list_part, const int debug);
-static const unsigned char *get_partition_name_none(const t_partition *partition);
-static const unsigned char *get_partition_name_none_aux(const unsigned int part_type_none);
+static const char *get_partition_name_none(const t_partition *partition);
+static const char *get_partition_name_none_aux(const unsigned int part_type_none);
 static unsigned int get_part_type_none(const t_partition *partition);
 
 static const struct systypes none_sys_types[] = {
@@ -348,7 +348,7 @@ static int check_part_none(t_param_disk *disk_car,const int debug,t_partition *p
   return ret;
 }
 
-static const unsigned char *get_partition_name_none_aux(const unsigned int part_type_none)
+static const char *get_partition_name_none_aux(const unsigned int part_type_none)
 {
   int i;
   for (i=0; none_sys_types[i].name!=NULL; i++)
@@ -357,7 +357,7 @@ static const unsigned char *get_partition_name_none_aux(const unsigned int part_
   return NULL;
 }
 
-static const unsigned char *get_partition_name_none(const t_partition *partition)
+static const char *get_partition_name_none(const t_partition *partition)
 {
   return get_partition_name_none_aux(partition->upart_type);
 }
