@@ -2,7 +2,7 @@
 
     File: partxbox.c
 
-    Copyright (C) 2005 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 2005-2006 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -55,8 +55,8 @@ static int test_structure_xbox(t_list_part *list_part);
 static int set_part_type_xbox(t_partition *partition, unsigned int part_type_xbox);
 static int is_part_known_xbox(const t_partition *partition);
 static void init_structure_xbox(const t_param_disk *disk_car,t_list_part *list_part, const int debug);
-static const unsigned char *get_partition_name_xbox(const t_partition *partition);
-static const unsigned char *get_partition_name_xbox_aux(const unsigned int part_type_xbox);
+static const char *get_partition_name_xbox(const t_partition *partition);
+static const char *get_partition_name_xbox_aux(const unsigned int part_type_xbox);
 static unsigned int get_part_type_xbox(const t_partition *partition);
 
 static const struct systypes xbox_sys_types[] = {
@@ -117,12 +117,33 @@ t_list_part *read_part_xbox(t_param_disk *disk_car, const int debug, const int s
   if(disk_car->read(disk_car,sizeof(buffer), &buffer, 0)!=0)
     return new_list_part;
   {
+    uint64_t offsets[]={ 0x00080000, 0x2ee80000, 0x5dc80000, 0x8ca80000, 0xabe80000 };
+    unsigned int i;
     struct xbox_partition *xboxlabel=(struct xbox_partition*)&buffer;
     if (memcmp(xboxlabel->magic,"BRFR",4))
     {
       aff_buffer(BUFFER_ADD,"\nBad XBOX partition, invalid signature\n");
       return NULL;
     }
+    for(i=0;i<sizeof(offsets)/sizeof(uint64_t);i++)
+    {
+      if(offsets[i]<disk_car->disk_size)
+      {
+	t_partition *partition=partition_new();
+	partition_reset(partition);
+	partition->part_type_xbox=PXBOX_FATX;
+	partition->part_offset=offsets[i];
+	partition->order=1+i;
+	if(i==sizeof(offsets)/sizeof(uint64_t)-1 || disk_car->disk_size<=offsets[i+1])
+	  partition->part_size=disk_car->disk_size-offsets[i];
+	else
+	  partition->part_size=offsets[i+1]-offsets[i];
+	partition->status=STATUS_PRIM;
+	new_list_part=insert_new_partition(new_list_part, partition);
+	disk_car->arch->check_part(disk_car,debug,partition,saveheader);
+	aff_part_buffer(AFF_PART_ORDER,disk_car,partition);
+      }
+    }
   }
   return new_list_part;
 }
@@ -172,16 +193,18 @@ static t_list_part *add_partition_xbox(t_param_disk *disk_car,t_list_part *list_
       wmove(stdscr,10, 0);
       wclrtoeol(stdscr);
       aff_part(stdscr,AFF_PART_SHORT,disk_car,new_partition);
-      wmove(stdscr,COMMAND_LINE_Y, COMMAND_LINE_X);
+      wmove(stdscr,INTER_GEOM_Y, INTER_GEOM_X);
       wclrtoeol(stdscr);
       wrefresh(stdscr);
       command=wmenuSimple(stdscr,menuGeometry, position);
       switch (command) {
 	case 'c':
+	  wmove(stdscr, INTER_GEOM_Y, INTER_GEOM_X);
 	  start.cylinder=ask_number(start.cylinder,0,disk_car->CHS.cylinder,"Enter the starting cylinder ");
 	  position=1;
 	  break;
 	case 'C':
+	  wmove(stdscr, INTER_GEOM_Y, INTER_GEOM_X);
 	  end.cylinder=ask_number(end.cylinder,start.cylinder,disk_car->CHS.cylinder,"Enter the ending cylinder ");
 	  position=2;
 	  break;
@@ -319,6 +342,8 @@ static int check_part_xbox(t_param_disk *disk_car,const int debug,t_partition *p
   {
     case PXBOX_FATX:
       ret=check_FATX(disk_car,partition,debug);
+      if(ret!=0)
+      { aff_buffer(BUFFER_ADD,"Invalid FATX signature\n"); }
       break;
     default:
       if(debug>0)
@@ -339,7 +364,7 @@ static int check_part_xbox(t_param_disk *disk_car,const int debug,t_partition *p
   return ret;
 }
 
-static const unsigned char *get_partition_name_xbox_aux(const unsigned int part_type_xbox)
+static const char *get_partition_name_xbox_aux(const unsigned int part_type_xbox)
 {
   int i;
   for (i=0; xbox_sys_types[i].name!=NULL; i++)
@@ -348,7 +373,7 @@ static const unsigned char *get_partition_name_xbox_aux(const unsigned int part_
   return NULL;
 }
 
-static const unsigned char *get_partition_name_xbox(const t_partition *partition)
+static const char *get_partition_name_xbox(const t_partition *partition)
 {
   return get_partition_name_xbox_aux(partition->part_type_xbox);
 }
