@@ -53,7 +53,7 @@ struct file_hint_struct
   const char *extension;
   const char *description;
   const uint64_t min_header_distance;
-  const uint64_t min_filesize;
+  uint64_t min_filesize;
   /* don't try head_check if min_header_distance >0 and previous_header_distance <= min_header_distance */
   /* needed by tar header */
   const uint64_t max_filesize;
@@ -66,12 +66,13 @@ struct file_hint_struct
 
 struct struct_alloc_data
 {
+  struct list_head list;
   uint64_t start;
   uint64_t end;
-  t_alloc_data *prev;
-  t_alloc_data *next;
   t_file_stat *file_stat;
 };
 
 int64_t test_jpeg(FILE *infile);
 void file_search_footer(t_file_recovery *file_recovery, const unsigned char*footer, const unsigned int footer_length);
+void file_search_lc_footer(t_file_recovery *file_recovery, const unsigned char*footer, const unsigned int footer_length);
+t_alloc_data *del_search_space(t_alloc_data *list_search_space, uint64_t start, uint64_t end);
