@@ -233,6 +233,7 @@ void dal_close(dal_t *dal) {
 	if (!dal) return;
 	
 	dal->ops = NULL;
+	free(dal->data);
 	dal->data = NULL;
 	free(dal);
 }
@@ -462,20 +463,22 @@ int dir_partition_reiser_init(t_param_disk *disk_car, const t_partition *partiti
   dal_t *dal;
   reiserfs_fs_t *fs;
   reiserfs_path_node_t *leaf;
-  t_my_data my_data;
+  t_my_data *my_data;
   int32_t offset = 0;
   int error = 0;
-  my_data.partition=partition;
-  my_data.disk_car=disk_car;
-  my_data.offset=0;
+  my_data=MALLOC(sizeof(*my_data));
+  my_data->partition=partition;
+  my_data->disk_car=disk_car;
+  my_data->offset=0;
 #ifdef HAVE_STRUCT_DAL_OPS_DEV
-  dal=dal_open(&ops, "",DEFAULT_BLOCK_SIZE, O_RDONLY, &my_data);
+  dal=dal_open(&ops, "",DEFAULT_BLOCK_SIZE, O_RDONLY, my_data);
 #else
-  dal=dal_open(&ops, DEFAULT_BLOCK_SIZE, O_RDONLY, &my_data);
+  dal=dal_open(&ops, DEFAULT_BLOCK_SIZE, O_RDONLY, my_data);
 #endif
   if (!dal)
   {
     ecrit_rapport("Couldn't open device\n");
+    free(my_data);
     return -1;
   }
   /* ecrit_rapport("file_open ok\n"); */
@@ -487,6 +490,7 @@ int dir_partition_reiser_init(t_param_disk *disk_car, const t_partition *partiti
 #endif
     {
       ecrit_rapport("Couldn't open reiser filesystem %s\n",dal_error(dal));
+      /* file_close call free(my_data) */
       file_close(dal);
       return -1;
     }
