@@ -2,7 +2,7 @@
 
     File: savehdr.h
 
-    Copyright (C) 2004 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 2004,2006 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,18 +15,18 @@
     GNU General Public License for more details.
   
     You should have received a copy of the GNU General Public License along
-    with this program; if not, write the Free Software Foundation, Inc., 59
-    Temple Place - Suite 330, Boston MA 02111-1307, USA.
+    with this program; if not, write the Free Software Foundation, Inc., 51
+    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  */
+#include "list.h"
 typedef struct backup_disk t_backup_disk;
 struct backup_disk
 {
+  struct list_head list;
   time_t my_time;
   char description[128];
   t_list_part *list_part;
-  t_backup_disk *prev;
-  t_backup_disk *next;
 };
 
 int save_header(t_param_disk *disk_car,t_partition *partition, const int debug);
