@@ -67,12 +67,11 @@ static int session_create_empty()
   return 0;
 }
 
-int session_load(char **cmd_device, char **current_cmd, t_alloc_data **list_free_space)
+int session_load(char **cmd_device, char **current_cmd, t_alloc_data *list_free_space)
 {
   FILE *f_session;
   char *buffer;
   char *pos;
-  t_alloc_data *current_free_space;
   int taille;
   f_session=fopen(SESSION_FILENAME,"rb");
   if(!f_session)
@@ -127,7 +126,6 @@ int session_load(char **cmd_device, char **current_cmd, t_alloc_data **list_free
     *pos='\0';
     pos++;
     *current_cmd=strdup(info);
-    current_free_space=*list_free_space;
     do
     {
       long unsigned start,end;
@@ -140,14 +138,8 @@ int session_load(char **cmd_device, char **current_cmd, t_alloc_data **list_free
 	  /* Temporary storage, values need to be multiply by sector_size */
 	  new_free_space->start=start;
 	  new_free_space->end=end;
-	  new_free_space->prev=current_free_space;
-	  new_free_space->next=NULL;
 	  new_free_space->file_stat=NULL;
-	  if(current_free_space!=NULL)
-	    current_free_space->next=new_free_space;
-	  current_free_space=new_free_space;
-	  if(*list_free_space==NULL)
-	    *list_free_space=current_free_space;
+	  list_add_tail(&new_free_space->list, &list_free_space->list);
 #ifdef DEBUG
 	  ecrit_rapport(">%lu-%lu<\n",start,end);
 #endif
@@ -166,7 +158,7 @@ int session_load(char **cmd_device, char **current_cmd, t_alloc_data **list_free
 
 int session_save(t_alloc_data *list_free_space, t_param_disk *disk_car, const t_partition *partition, const t_file_stat *file_stats, const unsigned int blocksize, const int debug)
 {
-  t_alloc_data *cur_free_space;
+  struct list_head *free_walker = NULL;
   FILE *f_session;
   unsigned int i;
   if(debug>1)
@@ -188,9 +180,13 @@ int session_save(t_alloc_data *list_free_space, t_param_disk *disk_car, const t_
     }
   }
   fprintf(f_session,"search,inter\n");
-  for(cur_free_space=list_free_space;cur_free_space!=NULL;cur_free_space=cur_free_space->next)
-    fprintf(f_session,"%lu-%lu\n",(long unsigned)(cur_free_space->start/disk_car->sector_size),
-	(long unsigned)(cur_free_space->end/disk_car->sector_size));
+  list_for_each(free_walker, &list_free_space->list)
+  {
+    t_alloc_data *current_free_space;
+    current_free_space=list_entry(free_walker, t_alloc_data, list);
+    fprintf(f_session,"%lu-%lu\n",(long unsigned)(current_free_space->start/disk_car->sector_size),
+	(long unsigned)(current_free_space->end/disk_car->sector_size));
+  }
   fclose(f_session);
   return 0;
 }
