@@ -19,6 +19,6 @@
     Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  */
-int session_load(char **cmd_device, char **current_cmd, t_alloc_data **list_free_space);
+int session_load(char **cmd_device, char **current_cmd, t_alloc_data *list_free_space);
 int session_save(t_alloc_data *list_free_space, t_param_disk *disk_car, const t_partition *partition, const t_file_stat *file_stats, const unsigned int blocksize, const int debug);
 
