@@ -2,7 +2,7 @@
 
     File: swap.c
 
-    Copyright (C) 1998-2005 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 1998-2006 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,17 +15,21 @@
     GNU General Public License for more details.
   
     You should have received a copy of the GNU General Public License along
-    with this program; if not, write the Free Software Foundation, Inc., 59
-    Temple Place - Suite 330, Boston MA 02111-1307, USA.
+    with this program; if not, write the Free Software Foundation, Inc., 51
+    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  */
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
  
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
+#include <stdio.h>
 #include "types.h"
 #include "common.h"
 #include "swap.h"
@@ -34,12 +38,19 @@ static int set_Linux_SWAP_info(const union swap_header *swap_header,t_partition
 
 int check_Linux_SWAP(t_param_disk *disk_car,t_partition *partition,const int debug)
 {
-  unsigned char buffer[8*DEFAULT_SECTOR_SIZE];
-  if(disk_car->read(disk_car,sizeof(buffer), &buffer, partition->part_offset)!=0)
-  { return 1; }
-  if(test_Linux_SWAP(disk_car,(union swap_header*)&buffer,partition,debug,0)!=0)
+  unsigned char *buffer=(unsigned char*)MALLOC(SWAP_SIZE);
+  if(disk_car->read(disk_car,SWAP_SIZE, buffer, partition->part_offset)!=0)
+  {
+    free(buffer);
     return 1;
-  set_Linux_SWAP_info((union swap_header*)&buffer,partition);
+  }
+  if(test_Linux_SWAP(disk_car,(union swap_header*)buffer,partition,debug,0)!=0)
+  {
+    free(buffer);
+    return 1;
+  }
+  set_Linux_SWAP_info((union swap_header*)buffer,partition);
+  free(buffer);
   return 0;
 }
 
