@@ -63,6 +63,7 @@
 #include "rfs_dir.h"
 #include "ntfs_dir.h"
 #include "hdcache.h"
+#include "ewf.h"
 extern const t_arch_fnct arch_i386;
 extern const t_arch_fnct arch_mac;
 extern const t_arch_fnct arch_sun;
@@ -240,14 +241,14 @@ int main( int argc, char **argv )
 	"- ReiserFS 3.5, 3.6 and 4               - Sun Solaris i386 disklabel\n" \
 	"- UFS and UFS2 (Sun/BSD/...)            - XFS, SGI's Journaled File System\n" \
 	"\n" \
-	"If you have problems with TestDisk or bug reports, please contacte me.\n");
+	"If you have problems with TestDisk or bug reports, please contact me.\n");
     return 0;
   }
   aff_buffer(BUFFER_RESET,"Q");
   if(do_list!=0)
   {
     printf("Please wait...\n");
-    /* Scan for avaible device only if no device or image has been supplied in parameter */
+    /* Scan for available device only if no device or image has been supplied in parameter */
     if(list_disk==NULL)
       list_disk=hd_parse(list_disk,debug,arch,testdisk_mode);
     /* Activate the cache */
@@ -286,7 +287,7 @@ int main( int argc, char **argv )
   {
     ecrit_rapport("TestDisk %s, Data Recovery Utility, %s\nChristophe GRENIER <grenier@cgsecurity.org>\nhttp://www.cgsecurity.org\n",VERSION,TESTDISKDATE);
     ecrit_rapport(TESTDISK_OS);
-    ecrit_rapport(" (ext2fs lib: %s, ntfs lib: %s, reiserfs lib: %s)\n",td_ext2fs_version(),td_ntfs_version(),td_reiserfs_version());
+    ecrit_rapport(" (ext2fs lib: %s, ntfs lib: %s, reiserfs lib: %s, ewf lib: %s)\n",td_ext2fs_version(),td_ntfs_version(),td_reiserfs_version(), td_ewf_version());
   }
 #ifdef HAVE_SETLOCALE
   if(run_setlocale>0)
@@ -304,7 +305,7 @@ int main( int argc, char **argv )
   aff_copy(stdscr);
   wmove(stdscr,5,0);
   wdoprintf(stdscr, "Please wait...\n");
-  /* Scan for avaible device only if no device or image has been supplied in parameter */
+  /* Scan for available device only if no device or image has been supplied in parameter */
   if(list_disk==NULL)
     list_disk=hd_parse(list_disk,debug,arch,testdisk_mode);
   /* Activate the cache */
