@@ -2,7 +2,7 @@
 
     File: ufs.c
 
-    Copyright (C) 2005 Christophe GRENIER <grenier@cgsecurity.org>
+    Copyright (C) 2005-2006 Christophe GRENIER <grenier@cgsecurity.org>
   
     This software is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,8 +15,8 @@
     GNU General Public License for more details.
   
     You should have received a copy of the GNU General Public License along
-    with this program; if not, write the Free Software Foundation, Inc., 59
-    Temple Place - Suite 330, Boston MA 02111-1307, USA.
+    with this program; if not, write the Free Software Foundation, Inc., 51
+    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  */
 
@@ -24,6 +24,9 @@
 #include <config.h>
 #endif
  
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
@@ -38,13 +41,22 @@ static int test_ufs(const t_param_disk *disk_car, const struct ufs_super_block *
 
 int check_ufs(t_param_disk *disk_car,t_partition *partition,const int debug)
 {
-  unsigned char buffer[2048];
-  const struct ufs_super_block*sb=(const struct ufs_super_block*)buffer;
-  if(disk_car->read(disk_car,sizeof(buffer), &buffer, partition->part_offset+UFS_SBLOCK)!=0)
-  { return 1; }
-  if(test_ufs(disk_car,sb,partition,debug,0)!=0)
+  const struct ufs_super_block*sb;
+  unsigned char *buffer;
+  buffer=(unsigned char*)MALLOC(UFS_SUPERBLOCK_SIZE);
+  sb=(const struct ufs_super_block*)buffer;
+  if(disk_car->read(disk_car,UFS_SUPERBLOCK_SIZE, buffer, partition->part_offset+UFS_SBLOCK)!=0)
+  {
+    free(buffer);
     return 1;
+  }
+  if(test_ufs(disk_car,sb,partition,debug,0)!=0)
+  {
+    free(buffer);
+    return 1;
+  }
   set_ufs_info(disk_car,sb,partition,debug,0);
+  free(buffer);
   return 0;
 }
 
@@ -53,14 +65,14 @@ static int test_ufs(const t_param_disk *disk_car, const struct ufs_super_block *
   if (le32(sb->fs_magic)==UFS_MAGIC || be32(sb->fs_magic)==UFS_MAGIC)
   {
     partition->upart_type = UP_UFS;
-    if(debug>0)
+    if(debug>1)
       ecrit_rapport("\nUFS Marker at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
     return 0;
   }
   else if (le32(sb->fs_magic)==UFS2_MAGIC || be32(sb->fs_magic)==UFS2_MAGIC)
   {
     partition->upart_type = UP_UFS2;
-    if(debug>0)
+    if(debug>1)
       ecrit_rapport("\nUFS2 Marker at %u/%u/%u\n", offset2cylinder(disk_car,partition->part_offset),offset2head(disk_car,partition->part_offset),offset2sector(disk_car,partition->part_offset));
     return 0;
   }
@@ -71,28 +83,28 @@ int recover_ufs(t_param_disk *disk_car, const struct ufs_super_block *sb, t_part
 {
   if(test_ufs(disk_car,sb,partition,debug,dump_ind)!=0)
     return 1;
-  if(debug>0 || dump_ind!=0)
+  if(dump_ind!=0)
   {
-    ecrit_rapport("\nrecover_ufs\n");
-    if(dump_ind!=0)
-    {
-      dump(stdscr,sb,sizeof(*sb));
-    }
+    ecrit_rapport("recover_ufs\n");
+    dump(stdscr,sb,sizeof(*sb));
   }
   switch(le32(sb->fs_magic))
   {
     case UFS_MAGIC:
       partition->part_size = (uint64_t)le32(sb->fs_size)*le32(sb->fs_fsize);
-      if(debug>0)
+      if(debug>1)
       {
 	ecrit_rapport("fs_size %lu, fs_fsize %lu\n",(long unsigned)le32(sb->fs_size),(long unsigned)le32(sb->fs_fsize));
+	ecrit_rapport("fs_sblkno %lu\n", (long unsigned)le32(sb->fs_sblkno));
       }
       break;
     case UFS2_MAGIC:
       partition->part_size = (uint64_t)le64(sb->fs_u11.fs_u2.fs_size)*le32(sb->fs_fsize);
-      if(debug>0)
+      if(debug>1)
       {
 	ecrit_rapport("fs_size %lu, fs_fsize %lu\n", (long unsigned)le64(sb->fs_u11.fs_u2.fs_size), (long unsigned)le32(sb->fs_fsize));
+	ecrit_rapport("fs_sblkno %lu\n", (long unsigned)le32(sb->fs_sblkno));
+	ecrit_rapport("fs_sblockloc %llu\n", (long long unsigned)le64(sb->fs_u11.fs_u2.fs_sblockloc));
       }
       break;
   }
@@ -100,14 +112,14 @@ int recover_ufs(t_param_disk *disk_car, const struct ufs_super_block *sb, t_part
   {
     case UFS_MAGIC:
       partition->part_size = (uint64_t)be32(sb->fs_size)*be32(sb->fs_fsize);
-      if(debug>0)
+      if(debug>1)
       {
 	ecrit_rapport("fs_size %lu, fs_fsize %lu\n",(long unsigned)be32(sb->fs_size),(long unsigned)be32(sb->fs_fsize));
       }
       break;
     case UFS2_MAGIC:
       partition->part_size = (uint64_t)be64(sb->fs_u11.fs_u2.fs_size)*be32(sb->fs_fsize);
-      if(debug>0)
+      if(debug>1)
       {
 	ecrit_rapport("fs_size %lu, fs_fsize %lu\n", (long unsigned)be64(sb->fs_u11.fs_u2.fs_size), (long unsigned)be32(sb->fs_fsize));
       }
